--******************************************************************************************************************************
--* Licensed Materials - Property of IBM                                                                                       *
--* (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
--*                                                                                                                            *
--*US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
--******************************************************************************************************************************

--=============  Create the model for NF schema 

ALTER SESSION SET CURRENT_SCHEMA= &&NF_SCHEMA;

CREATE TABLE CUSTOMER (
		CUSTOMER_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Customer Name Missing' NOT NULL,
		CUST_REFID VARCHAR(100),
		COMPANY_NAME VARCHAR(255),
		GEO_LOCATION VARCHAR(255),
		CONTACT_EMAIL VARCHAR(255),
		CONTACT_PHONE VARCHAR(255),
		CONTACT_FAX VARCHAR(255),
		CONTACT_ADDRESS VARCHAR(255),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ACTIVITY (
		ACTIVITY_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Missing Acivity Name' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		ACTIVITY_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		TASK_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROFILE_ID INTEGER DEFAULT -1 NOT NULL,
		FAILED_BUILD INTEGER DEFAULT -1 NOT NULL,
		CREATION_DATE TIMESTAMP,
		VALIDATION_BUILD INTEGER DEFAULT -1 NOT NULL,
		NOTEST_BUILD INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INTEGER DEFAULT -1 NOT NULL,
		CHARGECODE_ID INTEGER DEFAULT -1 NOT NULL,
		ACTIVITY_STATE VARCHAR(255),
		PRIORITY VARCHAR(255),
		STATUS VARCHAR(255),
		RESOLUTION VARCHAR(255),
		ACTIVITY_TYPE VARCHAR(255),
		RESOLUTION_CODE VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ACTIVITY_CLASSIFICATION (
		ACTIVITY_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Activity Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_ACTIVITY_LOOKUP(
		REQUEST_ID INTEGER NOT NULL,
		ACTIVITY_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE COMPONENT (
		COMPONENT_ID INTEGER NOT NULL,
		COMPONENT_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Component Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PRODUCT_ID INTEGER DEFAULT -1 NOT NULL,
		PARENT_COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_COMPONENT_LOOKUP (
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL
	) TABLESPACE VNF_32K ;
	
CREATE TABLE COMPONENT_CLASSIFICATION (
		COMPONENT_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Component Class Name Missing' NOT NULL
	) TABLESPACE VNF_32K ;
	
CREATE TABLE BUILD_CLASSIFICATION (
		BUILD_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Component Class Name Missing' NOT NULL
	) TABLESPACE VNF_32K ;

CREATE TABLE BUILD (
		BUILD_ID INTEGER NOT NULL,
		BUILD_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Build Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		BASELINE_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		TEAM_ID INTEGER DEFAULT -1 NOT NULL,
		BUILD_STATE VARCHAR(255),
		STATUS VARCHAR(255),
		START_TIME TIMESTAMP,
		END_TIME TIMESTAMP,
		BUILD_TYPE VARCHAR(255),
		CREATION_DATE TIMESTAMP,
		WAITING_TIME INTEGER,        
		BUILDING_TIME INTEGER,        
		ENGINE VARCHAR(255),		
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT (
		REQUIREMENT_ID INTEGER NOT NULL,
		REQUIREMENT_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Requirement Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		PLANNED_ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		ACTUAL_ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		RELEASE_ID INTEGER DEFAULT -1 NOT NULL,
		STATUS VARCHAR(255),
		REQUIREMENT_TYPE VARCHAR(255),
		REQUIREMENT_STATE VARCHAR(255),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		DIFFICULTY VARCHAR(255),
		STABILITY VARCHAR(255),
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		CREATION_DATE TIMESTAMP,
		PRIORITY VARCHAR(255),
		CUSTOMER_PRIORITY VARCHAR(255),
		PLATFORM VARCHAR(255),
		REVISION_NUMBER VARCHAR(50),
		REVISION_DATE TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_REVISION_HISTORY (
		REQUIREMENT_REVISION_ID INTEGER NOT NULL,
		REQUIREMENT_ID INTEGER NOT NULL,
		REVISION_NUMBER VARCHAR(50) DEFAULT '0' NOT NULL,
		RESOURCE_ID INTEGER DEFAULT -1 NOT NULL,
		CHANGE_DATE DATE DEFAULT CURRENT_DATE NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

	
CREATE TABLE TESTSUITE (
		TESTSUITE_ID INTEGER NOT NULL,
	    TESTSUITE_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'TestSuite Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INTEGER DEFAULT -1 NOT NULL,
		ASSETREGISTRY_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		TESTSUITE_STATE VARCHAR(255),
		LAST_UPDATED TIMESTAMP,
		CREATION_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECUTION_RESULT (
		EXECUTION_RESULT_ID INTEGER DEFAULT -1 NOT NULL,
		EXECRES_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Execution Result Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		VERDICT VARCHAR(255),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		BUILD_ID INTEGER DEFAULT -1 NOT NULL,
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		TESTTYPE_ID INTEGER DEFAULT -1 NOT NULL,
		TESTCASE_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		TESTSCRIPT_ID INTEGER DEFAULT -1 NOT NULL,
		START_DATE TIMESTAMP,
		END_DATE TIMESTAMP,
		POINTS_BLOCKED INTEGER DEFAULT 0 NOT NULL,
		POINTS_INCONCLUSIVE INTEGER DEFAULT 0 NOT NULL,
		MACHINE VARCHAR(255),
		POINTS_ATTEMPTED INTEGER DEFAULT 0 NOT NULL,
		POINTS_FAILED INTEGER DEFAULT 0 NOT NULL,
		POINTS_PASSED INTEGER DEFAULT 0 NOT NULL,
		POINTS_PERMFAILED INTEGER DEFAULT 0 NOT NULL,
		LAST_UPDATED TIMESTAMP,
		CREATION_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CURRENCY (
		CURRENCY_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Currency Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		EXCHANGE_RATE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		VALID_START_DATE TIMESTAMP,
		VALID_FINISH_DATE TIMESTAMP,
		DEFAULT_CURRENCY INTEGER DEFAULT 0 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE OPERATING_TERRITORY(
		TERRITORY_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Territory Name Missing' NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE COUNTRY (
		COUNTRY_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Country Name Missing' NOT NULL,
		TERRITORY_ID INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROVINCE_STATE (
		PROVINCE_STATE_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Province or State Name Missing' NOT NULL,
		COUNTRY_ID INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CITY (
		CITY_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'City Name Missing' NOT NULL,
		PROVINCE_STATE_ID INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ORGANIZATION (
		ORGANIZATION_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Organization Name Missing' NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE POOL (
		POOL_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Pool Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PARENT_POOL_ID INTEGER DEFAULT -1 NOT NULL ,
		POOL_TYPE VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE "RESOURCE" (
		RESOURCE_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Resource Logon Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		FULL_NAME VARCHAR(110) DEFAULT 'Resource Full Name Missing' NOT NULL,
		FIRST_NAME VARCHAR(35),
		LAST_NAME VARCHAR(35),
		MIDDLE_INITIAL VARCHAR(35),
		RESOURCE_TYPE SMALLINT,
		STANDARD_RATE DECIMAL(18 , 2),
		OVERTIME_RATE DECIMAL(18 , 2),
		POOL_ID INTEGER DEFAULT -1 NOT NULL,
		CITY_ID INTEGER DEFAULT -1 NOT NULL,
		ORGANIZATION_ID INTEGER DEFAULT -1 NOT NULL,
		EFFECTIVE_DATE DATE,
		DISCONTINUE_DATE DATE,
		TIME_PER_DAY INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE SKILL (
		SKILL_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Skill Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RESOURCE_SKILL_LOOKUP (
		RESOURCE_ID INTEGER NOT NULL,
		SKILL_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE COMPETENCY (
		COMPETENCY_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Competency Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RESOURCE_COMPETENCY_LOOKUP (
		RESOURCE_ID INTEGER NOT NULL,
		COMPETENCY_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_BASELINE (
		BASELINE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Baseline Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		TASK_ID INTEGER DEFAULT -1 NOT NULL,
		BASELINE_DATE TIMESTAMP,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		PLANNED_WORK INTEGER,
		PLANNED_COST DECIMAL(18 , 2),
		PLANNED_DURATION INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_CLASSIFICATION (
		TASK_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Task Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_CATEGORY (
		TASK_CATEGORY_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Task Category Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		CATEGORY_TYPE VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PRODUCT (
		PRODUCT_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Product Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ASSETREGISTRY (
		ASSETREGISTRY_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'AssetRegistry Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ITERATION (
		ITERATION_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Iteration Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		ASSETREGISTRY_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		PHASE_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT-1 NOT NULL,
		STATUS VARCHAR(255),
		START_DATE TIMESTAMP,
		END_DATE TIMESTAMP,
		EXPECTED_START_DATE TIMESTAMP,
		EXPECTED_END_DATE TIMESTAMP,
		EXPECTED_TOTAL_POINTS INTEGER DEFAULT 0 NOT NULL,
		EXPECTED_DEFECTS INTEGER DEFAULT 0 NOT NULL,
		EXPECTED_VALIDITY_RATE DECIMAL (18,2) DEFAULT 0.00 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ITERATION_DETAIL (
		ITERATION_ID INTEGER NOT NULL,
		ACTUAL_DURATION INTEGER DEFAULT 0 NOT NULL,       
		ACTUAL_WORK INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_WORK_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_START_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_FINISH_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_START DATE,
		ACTUAL_FINISH DATE,
		ACTUAL_COST  DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		ACTUAL_COST_VARIANCE DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		BASELINE_DURATION INTEGER  DEFAULT 0 NOT NULL,
		BASELINE_WORK INTEGER DEFAULT 0 NOT NULL,
		BASELINE_WORK_VARIANCE  INTEGER  DEFAULT 0 NOT NULL,
		BASELINE_FINISH_VARIANCE  INTEGER  DEFAULT 0 NOT NULL,
		BASELINE_START_VARIANCE  INTEGER  DEFAULT 0 NOT NULL,
		BASELINE_COST_VARIANCE DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		BASELINE_START DATE,
		BASELINE_FINISH DATE,
		PLANNED_COST DECIMAL(18,2) DEFAULT 0.00 NOT NULL,         
		COST_VARIANCE  DECIMAL(18,2) DEFAULT 0.00 NOT NULL,
		PLANNED_DURATION INTEGER  DEFAULT 0 NOT NULL,      
		PLANNED_WORK INTEGER  DEFAULT 0 NOT NULL,
		WORK_VARIANCE INTEGER  DEFAULT 0 NOT NULL,
		START_VARIANCE  INTEGER  DEFAULT 0 NOT NULL,
		FINISH_VARIANCE  INTEGER  DEFAULT 0 NOT NULL,        
		DURATION_VARIANCE INTEGER  DEFAULT 0 NOT NULL,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2)
) TABLESPACE VNF_32K ;

CREATE TABLE ITERATION_BASELINE (
		BASELINE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Iteration Baseline Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		BASELINE_DATE TIMESTAMP,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		PLANNED_WORK INTEGER,
		BASELINE_WORK_COMPLETED INTEGER,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST_COMPLETED DECIMAL(18 , 2),
		PLANNED_DURATION INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RELEASE (
		RELEASE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Release Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		PRODUCT_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		AVAILABILITY_DATE DATE,
		DECOMISSION_DATE DATE,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROGRAM (
		PROGRAM_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Program Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROGRAM_MANAGER INTEGER DEFAULT -1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;
		
CREATE TABLE PROGRAM_DETAIL (
		PROGRAM_ID INTEGER NOT NULL,
        CURRENCY_ID INTEGER DEFAULT -1 NOT NULL,
		ACTUAL_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		CURRENT_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_VARIANCE INTEGER DEFAULT 0,
		ACTUAL_START DATE,
		ACTUAL_FINISH DATE,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		ACWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWS DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_ETC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_FLAG DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_DURATION INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_WORK INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_WORK_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_START_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_FINISH_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_DURATION INTEGER DEFAULT 0 NOT NULL,
		PLANNED_WORK INTEGER DEFAULT 0 NOT NULL,
		WORK_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		START_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		FINISH_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		DURATION_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		PERCENT_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL,
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT (
		PROJECT_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Project Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROGRAM_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_MANAGER INTEGER DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INTEGER DEFAULT -1 NOT NULL,
		START_DATE TIMESTAMP,
		END_DATE TIMESTAMP,
		SHIP_DATE TIMESTAMP,
		PRIORITY VARCHAR(255),
		STATUS VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK (
		TASK_ID INTEGER NOT NULL,
		TASK_CATEGORY_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Task Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		TASK_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		TASK_STATE VARCHAR(255),
		PRIORITY VARCHAR(255),
		STATUS VARCHAR(255),
		RESOLUTION VARCHAR(255),
		TASK_TYPE VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_HIERARCHY (
		PARENT_PROJECT_ID INTEGER NOT NULL,
		CHILD_PROJECT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_DETAIL (
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		CURRENCY_ID INTEGER DEFAULT -1 NOT NULL,
		BASELINE_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_START DATE,
		BASELINE_FINISH DATE,
		BASELINE_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		BASELINE_ESTIMATED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_ESTIMATED_START DATE,
		BASELINE_ESTIMATED_FINISH DATE,
		ACTUAL_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		CURRENT_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_VARIANCE INTEGER DEFAULT 0,
		ACTUAL_START DATE,
		ACTUAL_FINISH DATE,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		ACWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWS DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_ETC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_FLAG DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_DURATION INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_WORK INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_WORK_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_START_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_FINISH_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_DURATION INTEGER DEFAULT 0 NOT NULL,
		BASELINE_WORK INTEGER DEFAULT 0 NOT NULL,
		BASELINE_WORK_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		BASELINE_START_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		BASELINE_FINISH_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		BASELINE_COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		COST_VARIANCE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_DURATION INTEGER DEFAULT 0 NOT NULL,
		PLANNED_WORK INTEGER DEFAULT 0 NOT NULL,
		WORK_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		START_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		FINISH_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		DURATION_VARIANCE INTEGER DEFAULT 0 NOT NULL,
		PERCENT_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL,
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2) DEFAULT 0.00 NOT NULL
	) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_ALLOCATION (
		PROJECT_ALLOCATION_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Project Assignment Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROFILE_ID INTEGER DEFAULT -1 NOT NULL,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		ACTUAL_START DATE,
		ACTUAL_FINISH DATE,
		PLANNED_WORK INTEGER DEFAULT 0 NOT NULL,
		ACTUAL_WORK INTEGER DEFAULT 0 NOT NULL,
		PLANNED_DURATION INTEGER,
		ACTUAL_DURATION INTEGER,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		ALLOTED_WORK INTEGER,
		UNITS INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;
	
CREATE TABLE PROJECT_TYPE (
		PROJECT_TYPE_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Project Type Name Missing' NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		RECORD_TYPE VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_WORKCONFIGURATION (
		PROJECT_WKCFG_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Work Configuartion Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		RECORD_TYPE VARCHAR(255),
		PROJECT_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_WORKCONFIG_HIERARCHY (
		PARENT_WKCFG_ID INTEGER NOT NULL,
		CHILD_WKCFG_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_CLASSIFICATION (
		PROJECT_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Project Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_CATEGORY (
		PROJECT_CATEGORY_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Project Category Name Missing' NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		CATEGORY_TYPE VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PHASE (
		PHASE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Project Phase Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		STATUS VARCHAR(255),
		START_DATE TIMESTAMP,
		END_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_ROLE (
		PROJECT_ROLE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Project Role Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_ROLE_MEMBER_LOOKUP (
		PROJECT_ROLE_ID INTEGER NOT NULL,
		RESOURCE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TEAM (
		TEAM_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Team Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_DETAIL (
		TASK_ID INTEGER DEFAULT -1 NOT NULL,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		BASELINE_START DATE,
		BASELINE_FINISH DATE,
		ACTUAL_START DATE,
		ACTUAL_FINISH DATE,
		PLANNED_WORK INTEGER DEFAULT 0 NOT NULL,
		BASELINE_WORK INTEGER,
		REGULAR_WORK INTEGER,
		ACTUAL_WORK INTEGER DEFAULT 0 NOT NULL,
		REMAINING_WORK INTEGER,
		PLANNED_DURATION INTEGER,
		BASELINE_DURATION INTEGER,
		ACTUAL_DURATION INTEGER,
		REMAINING_DURATION INTEGER,
		START_VARIANCE INTEGER,
		FINISH_VARIANCE INTEGER,
		DURATION_VARIANCE INTEGER,
		PLANNED_OVT_WORK INTEGER,
		ACTUAL_OVT_WORK INTEGER,
		REMAINING_OVT_WORK INTEGER,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST DECIMAL(18 , 2),
		ACTUAL_COST DECIMAL(18 , 2),
		REMAINING_COST DECIMAL(18 , 2),
		PLANNED_OVT_COST DECIMAL(18 , 2),
		ACTUAL_OVT_COST DECIMAL(18 , 2),
		REMAINING_OVT_COST DECIMAL(18 , 2),
		DEADLINE DATE,
		EARLY_START DATE,
		LATE_FINISH DATE,
		EARLY_FINISH DATE,
		LATE_START DATE,
		CONSTRAINT_TYPE INTEGER,
		CONSTRAINT_DATE DATE,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		ACWP BINARY_DOUBLE,
		BCWP BINARY_DOUBLE,
		BCWS BINARY_DOUBLE,
		EAC BINARY_DOUBLE,
		VAC BINARY_DOUBLE,
		WBS_CODE VARCHAR(255),
		ACTUAL_FINISH_VARIANCE INTEGER,
		BASELINE_FINISH_VARIANCE INTEGER,
		ACTUAL_WORK_VARIANCE INTEGER,
		BASELINE_WORK_VARIANCE INTEGER,
		ACTUAL_START_VARIANCE INTEGER,
		BASELINE_START_VARIANCE INTEGER,
		WORK_VARIANCE INTEGER
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_REQUIREMENT_LOOKUP (
		TASK_ID INTEGER NOT NULL,
		REQUIREMENT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CONFIGURATION (
		CONFIGURATION_ID INTEGER NOT NULL,
		CONFIGURATION_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Configuration Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT-1 NOT NULL,
		LAST_UPDATED TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CONFIGURATION_ATTRIBUTE (
		CONFIGURATION_ATTRIBUTE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Configuration_Attribute Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CONFIGURATION_ATTRIBUTE_LOOKUP (
		CONFIGURATION_ATTRIBUTE_ID INTEGER NOT NULL,
		CONFIGURATION_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITE_ITERATION_LOOKUP (
		TESTSUITE_ID INTEGER NOT NULL,
		ITERATION_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTPLAN (
		TESTPLAN_ID INTEGER NOT NULL,
		TESTPLAN_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'TestPlan Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		ASSETREGISTRY_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		LAST_UPDATED TIMESTAMP,
		TESTPLAN_STATE VARCHAR(255),
		CREATION_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTPLAN_ITERATION_LOOKUP (
		TESTPLAN_ID INTEGER NOT NULL,
		ITERATION_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTTYPE (
		TESTTYPE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'TestType Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTCASE (
		TESTCASE_ID INTEGER NOT NULL,
		TESTCASE_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'TestCase Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		TESTCASE_STATE VARCHAR(255),
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		TESTPLAN_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT-1 NOT NULL,
		IS_BLOCKING INTEGER DEFAULT 0 NOT NULL,
		REGRESSION_TEST VARCHAR(255),
		WEIGHT INTEGER DEFAULT 0,
		LAST_UPDATED TIMESTAMP,
		TESTCASE_FOLDER VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTCASE_TESTSCRIPT_LOOKUP (
		TESTCASE_ID INTEGER NOT NULL,
		TESTSCRIPT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTCASE_ITERATION_LOOKUP (
		TESTCASE_ID INTEGER NOT NULL,
		ITERATION_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_TESTCASE_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		TESTCASE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_TESTPLAN_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		TESTPLAN_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_TESTSUITE_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		TESTSUITE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_REQUIREMENT_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		CREQUIREMENT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_HIERARCHY (
		PRED_REQUIREMENT_ID INTEGER NOT NULL,
		SUCC_REQUIREMENT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECUTION_WORKITEM (
		EXECWORKITEM_ID INTEGER NOT NULL,
		EXECWORKIT_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Execution Work Item Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INTEGER DEFAULT -1 NOT NULL,
		EXECUTION_WORKITEM_STATE VARCHAR(255),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		TESTCASE_ID INTEGER DEFAULT -1 NOT NULL,
		TESTTYPE_ID INTEGER DEFAULT -1 NOT NULL,
		TESTPLAN_ID INTEGER DEFAULT -1 NOT NULL,
		TESTSCRIPT_ID INTEGER DEFAULT -1 NOT NULL,
		CURRENT_RESULT_ID INTEGER DEFAULT -1 NOT NULL,
		FREQUENCY VARCHAR(255),
		REGRESSION VARCHAR(255),
		WEIGHT INTEGER DEFAULT 0,
		TAGS VARCHAR(255),
		LAST_UPDATED TIMESTAMP,
		PRIORITY VARCHAR(255),
		CREATION_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECWORKITEM_ITERATION_LOOKUP (
		EXECWORKITEM_ID INTEGER NOT NULL,
		ITERATION_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_EXECWRKITEM_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		EXECWORKITEM_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECWORKITEM_TESTSUITE_LOOKUP (
		EXECWORKITEM_ID INTEGER NOT NULL,
		TESTSUITE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST (
		REQUEST_ID INTEGER NOT NULL,
		REQUEST_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Request Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		BUILD_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INTEGER DEFAULT -1 NOT NULL,
		PHASE_ID INTEGER DEFAULT -1 NOT NULL,
		SEVERITY VARCHAR(255),
		REQUEST_STATE VARCHAR(255),
		PRIORITY VARCHAR(255),
		PLATFORM VARCHAR(255),
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		RELEASE_ID INTEGER DEFAULT -1 NOT NULL,
		FIXEDINRELEASE_ID INTEGER DEFAULT -1 NOT NULL,
		SLOC_CHANGE INTEGER DEFAULT 0,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		REQUEST_CATEGORY_ID INTEGER DEFAULT -1 NOT NULL,
		TEAM_ID INTEGER DEFAULT -1 NOT NULL,
		RESOLVER_ID INTEGER DEFAULT -1 NOT NULL,
		IS_BLOCKING INTEGER DEFAULT 0 NOT NULL,
		REQUEST_SOURCE VARCHAR(255),
		CREATION_DATE TIMESTAMP,
		CLOSED_DATE TIMESTAMP,
		SUBMIT_DATE TIMESTAMP,
		RESOLVED_DATE TIMESTAMP,
		ASSIGNED_DATE TIMESTAMP,
		DUPLICATE_DATE TIMESTAMP,
		ACTIVATE_DATE TIMESTAMP,
		STATUS VARCHAR(255),
		CUSTOMER_PRIORITY VARCHAR(255),
		RESOLUTION VARCHAR(255),
		REQUEST_TYPE VARCHAR(255),
		PLANNED_WORK INTEGER,
		ACTUAL_WORK INTEGER,
		COMMENT_COUNT INTEGER,                             
		SUBSCRIBER_COUNT INTEGER,
		STORY_POINTS INTEGER,                          
		TAGS VARCHAR (255),
		SUMMARY VARCHAR (1000),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_CLASSIFICATION (
		REQUEST_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Request Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_CLASSIFICATION (
		REQUIREMENT_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Requirement Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_STATE_HISTORY (
		REQUEST_STATE_HISTORY_ID INTEGER NOT NULL,
		REQUEST_ID INTEGER NOT NULL,
		PREV_REQUEST_STATE VARCHAR(255),
		REQUEST_STATE VARCHAR(255),
		CHANGE_DATE DATE DEFAULT CURRENT_DATE NOT NULL,
		DAYS_IN_STATE INTEGER DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_HIERARCHY (
		PARENT_REQUEST_ID INTEGER NOT NULL,
		CHILD_REQUEST_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE FILE_VERSION (
		FILE_VERSION_ID INTEGER DEFAULT -1 NOT NULL,
		FILE_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'File Version Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		FILE_ID INTEGER DEFAULT -1 NOT NULL,
		CREATION_DATE TIMESTAMP NOT NULL,
		NUM_SLOC INTEGER DEFAULT 0 NOT NULL,
		NUM_SLOC_CHANGED INTEGER DEFAULT 0 NOT NULL,
		AUTHOR_ID INTEGER DEFAULT -1 NOT NULL,
		ACTIVITY_ID INTEGER DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INTEGER DEFAULT-1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		HASCOMMENT SMALLINT DEFAULT 0 NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE "FILE" (
		FILE_ID INTEGER NOT NULL,
		FILE_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'File Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		NUM_SLOC INTEGER DEFAULT 0 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE FILE_BASELINE (
		FILE_BASELINE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'File_Baseline Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE FILE_BASELINE_ACTIVITY_LOOKUP
		(FILE_BASELINE_ID INTEGER NOT NULL,
		ACTIVITY_ID INTEGER NOT NULL)
 TABLESPACE VNF_32K ;

CREATE TABLE FILE_STREAM (
		FILE_STREAM_ID INTEGER NOT NULL,
		FILE_STREAM_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'File_Stream Name Missing' NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CONFIG_EXECUTIONRES_LOOKUP (
		CONFIGURATION_ID INTEGER NOT NULL,
		EXECUTION_RESULT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITELOG (
		TESTSUITELOG_ID INTEGER NOT NULL,
		TESTSUITELOG_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Test Suite Log Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		VERDICT VARCHAR(255),
		TESTSUITE_ID INTEGER DEFAULT -1 NOT NULL,
		BUILD_ID INTEGER DEFAULT -1 NOT NULL,
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		START_DATE TIMESTAMP,
		END_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITELOG_EXECRESULT_LOOKUP (
		TESTSUITELOG_ID INTEGER NOT NULL,
		EXECUTION_RESULT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_REQUEST_LOOKUP (
		TASK_ID INTEGER NOT NULL,
		REQUEST_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_REQUEST_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		REQUEST_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_CUSTOMER_LOOKUP (
		REQUEST_ID INTEGER NOT NULL,
		CUSTOMER_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUIREMENT_CUSTOMER_LOOKUP (
		REQUIREMENT_ID INTEGER NOT NULL,
		CUSTOMER_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECRES_REQUEST_LOOKUP (
		REQUEST_ID INTEGER NOT NULL,
		EXECUTION_RESULT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RISK (
		RISK_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Risk Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		REQUIREMENT_ID INTEGER DEFAULT -1 NOT NULL,
		PRIORITY VARCHAR(255),
		RISK_STATE VARCHAR(255),
		OCCURED_DATETIME TIMESTAMP,
		IMPACT INTEGER,
		IMPACT_RANK VARCHAR(255),
		PROBABILITY INTEGER,
		PROBABILITY_RANK VARCHAR(255),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		RELEASE_ID INTEGER DEFAULT -1 NOT NULL,
		ITERATION_ID INTEGER DEFAULT -1 NOT NULL,
		TARGET_DATE TIMESTAMP,
		CREATION_DATE TIMESTAMP,
		CLOSE_DATE TIMESTAMP,
		IMPACT_CATEGORY VARCHAR(255),
		CONSEQUENCE_COST DECIMAL(18,2),
		PROBABILITY_COST DECIMAL(18,2),
		RISK_SCORE DECIMAL(18,2),
		RISK_MANAGEMENT_ACTION VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RISK_STATE_HISTORY (
		RISK_STATE_HISTORY_ID INTEGER NOT NULL,
		RISK_ID INTEGER NOT NULL,
		PREV_RISK_STATE VARCHAR(255),
		RISK_STATE VARCHAR(255),
		CHANGE_DATE DATE DEFAULT CURRENT_DATE NOT NULL,
		DAYS_IN_STATE INTEGER DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE FACTOR (
		FACTOR_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Factor Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		RISK_ID INTEGER DEFAULT -1 NOT NULL,
		MITIGATION_COST DECIMAL(18 , 2),
		PRIORITY VARCHAR(255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJECT_BASELINE (
		BASELINE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Project_Baseline Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INTEGER DEFAULT -1 NOT NULL,
		BASELINE_DATE TIMESTAMP,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		PLANNED_WORK INTEGER,
		BASELINE_WORK_COMPLETED INTEGER,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST_COMPLETED DECIMAL(18 , 2),
		PLANNED_DURATION INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROJ_BASELINE_BASELINE_LOOKUP (
		BASELINE_ID INTEGER NOT NULL,
		COMPBASELINE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE "COMMENT" (
		COMMENT_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		RESPONSE_COMMENT_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		REQUEST_ID INTEGER DEFAULT -1 NOT NULL,
		TASK_ID INTEGER DEFAULT -1 NOT NULL,
		ACTIVITY_ID INTEGER DEFAULT -1 NOT NULL,
		CREATION_DATE TIMESTAMP,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ACTIVITY_DETAIL (
		ACTIVITY_ID INTEGER DEFAULT -1 NOT NULL,
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		BASELINE_START DATE,
		ACTUAL_START DATE,
		BASELINE_FINISH DATE,
		ACTUAL_FINISH DATE,
		START_VARIANCE INTEGER,
		FINISH_VARIANCE INTEGER,
		PLANNED_WORK INTEGER,
		BASELINE_WORK INTEGER,
		REGULAR_WORK INTEGER,
		ACTUAL_WORK INTEGER,
		REMAINING_WORK INTEGER,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST DECIMAL(18 , 2),
		ACTUAL_COST DECIMAL(18 , 2),
		REMAINING_COST DECIMAL(18 , 2),
		PLANNED_OVT_WORK DECIMAL(18 , 2),
		ACTUAL_OVT_WORK DECIMAL(18 , 2),
		REMAINING_OVT_WORK DECIMAL(18 , 2),
		ACTUAL_OVT_COST DECIMAL(18 , 2),
		REMAINING_OVT_COST DECIMAL(18 , 2),
		UNITS INTEGER,
		DELAY INTEGER,
		ACWP BINARY_DOUBLE,
		BCWP BINARY_DOUBLE,
		BCWS BINARY_DOUBLE,
		EAC BINARY_DOUBLE,
		RESOURCE_TYPE CHAR(18),
		IS_OVERALLOCATED SMALLINT,
		IS_CONFIRMED SMALLINT,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		PLANNED_DURATION INTEGER,
		ACTUAL_DURATION INTEGER
) TABLESPACE VNF_32K ;

CREATE TABLE EXECRES_EXECWKITEM_LOOKUP (
		EXECUTION_RESULT_ID INTEGER NOT NULL,
		EXECWORKITEM_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CONFIG_EXECUTIONWORKITM_LOOKUP (
		CONFIGURATION_ID INTEGER NOT NULL,
		EXECWORKITEM_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TEST_CATEGORY (
		TEST_CATEGORY_ID INTEGER NOT NULL,
		NAME VARCHAR (255) DEFAULT 'Test Category Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		TERM VARCHAR (255),
		VALUE VARCHAR (255),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTPLAN_CATEGORY_LOOKUP (
		TEST_CATEGORY_ID INTEGER NOT NULL,
		TESTPLAN_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTCASE_CATEGORY_LOOKUP (
		TEST_CATEGORY_ID INTEGER NOT NULL,
		TESTCASE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITE_TESTCASE_LOOKUP (
		TESTCASE_ID INTEGER NOT NULL,
		TESTSUITE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITE_TESTSUITELOG_LOOKUP (
		TESTSUITE_ID INTEGER NOT NULL,
		TESTSUITELOG_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTPLAN_TESTPLAN_HIERARCHY (
		PARENT_TESTPLAN_ID INTEGER NOT NULL,
		CHILD_TESTPLAN_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTPLAN_TESTCASE_LOOKUP  (
		  TESTPLAN_ID INTEGER NOT NULL, 
		  TESTCASE_ID INTEGER NOT NULL)
TABLESPACE VNF_32K ;

CREATE TABLE LAB_RESOURCE (
			LAB_RESOURCE_ID INTEGER NOT NULL,
			NAME VARCHAR(255) DEFAULT 'Missing Lab Resource Name' NOT NULL,
			REFERENCE_ID VARCHAR(50),
			EXTERNAL_ID VARCHAR(100),
			LAB_RESOURCE_TYPE VARCHAR(255),
			LAB_RESOURCE_NAME VARCHAR(255),
			MEMORY INTEGER,
			IP_ADDRESS VARCHAR(40),
			PRIMARY_MAC_ADDRESS CHAR(18),
			ADMINISTRATIVE_STATUS VARCHAR(255),
			OPERATIONAL_STATUS VARCHAR(255),
			HOSTNAME VARCHAR(255),
			FULLY_QUALIFIED_DOMAIN_NAME VARCHAR(255),
			OS_TYPE VARCHAR(255),
			OS_LOCALE VARCHAR(255),
			OS_KERNEL_WIDTH VARCHAR(255),
			CPU_SPEED INTEGER,
			CPU_ARCHITECTURE VARCHAR(255),
			CPU_ARCHITECTURE_WIDTH VARCHAR(255),
			CPU_MANUFACTURER VARCHAR(255),
			CPU_TYPE VARCHAR(255), 
			DISK_SPACE INTEGER,
			SOFTWARE VARCHAR(255),
			RESOURCE_GROUP_ID INTEGER DEFAULT -1 NOT NULL,
			PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
			URL VARCHAR(2048),
			EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RESOURCE_GROUP (
			RESOURCE_GROUP_ID INTEGER NOT NULL,
			NAME VARCHAR(255) DEFAULT 'Missing Resource Group Name' NOT NULL,
			REFERENCE_ID VARCHAR(50),
			EXTERNAL_ID VARCHAR(100),
			PROJECT_ID INTEGER DEFAULT-1 NOT NULL,
			IS_EXPIREABLE VARCHAR(255),
			START_DATE TIMESTAMP,
			EXPIRATION_DATE TIMESTAMP,
			URL VARCHAR(2048),
			EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE RESERVATION (
			RESERVATION_ID INTEGER NOT NULL,
			NAME VARCHAR(255) DEFAULT 'Missing Reservation Name' NOT NULL,
			REFERENCE_ID VARCHAR(50),
			EXTERNAL_ID VARCHAR(100),
			RESERVED_FOR VARCHAR(255),
			RESERVED_BY VARCHAR(255),
			RESERVE_TO TIMESTAMP,
			RESERVE_FROM TIMESTAMP,
			LAB_RESOURCE_ID INTEGER DEFAULT -1 NOT NULL,
			PROJECT_ID INTEGER DEFAULT-1 NOT NULL,
			URL VARCHAR(2048),
			EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTCASE_CLASSIFICATION (
		TESTCASE_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Testcase Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTPLAN_CLASSIFICATION (
		TESTPLAN_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Testplan Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITE_CLASSIFICATION (
		TESTSUITE_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Testsuite Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSUITELOG_CLASSIFICATION (
		TESTSUITELOG_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Testsuitelog Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECRESULT_CLASSIFICATION (
		EXECRES_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Execution Result Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE EXECWORKITEM_CLASSIFICATION (
		EXECWORKIT_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Execution Work Item Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CONFIGURATION_CLASSIFICATION (
		CONFIGURATION_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Configuration Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ACTIVITY_STATE_HISTORY (
		ACTIVITY_STATE_HISTORY_ID INTEGER NOT NULL,
		ACTIVITY_ID INTEGER NOT NULL,
		PREV_ACTIVITY_STATE VARCHAR(255),
		ACTIVITY_STATE VARCHAR(255),
		CHANGE_DATE DATE DEFAULT CURRENT_DATE NOT NULL,
		DAYS_IN_STATE INTEGER DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_CATEGORY (
		REQUEST_CATEGORY_ID INTEGER NOT NULL,
		NAME VARCHAR(255) DEFAULT 'Request Category Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;
	
CREATE TABLE FILE_CLASSIFICATION (
		FILE_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'File Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE FILE_STREAM_CLASSIFICATION (
		FILE_STREAM_CLASS_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'File Stream Class Name Missing' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TASK_STATE_HISTORY (
		TASK_STATE_HISTORY_ID INTEGER NOT NULL,
		TASK_ID INTEGER NOT NULL,
		PREV_TASK_STATE VARCHAR(255),
		TASK_STATE VARCHAR(255),
		CHANGE_DATE DATE DEFAULT CURRENT_DATE NOT NULL,
		DAYS_IN_STATE INTEGER DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE REQUEST_CHANGE_HISTORY	(
		REQCHANGE_HISTORY_ID INTEGER NOT NULL,
		REQUEST_CLASS_ID INTEGER DEFAULT -1 NOT NULL,
		REQUEST_ID INTEGER DEFAULT -1 NOT NULL,                          
		PREV_TEAM_ID INTEGER DEFAULT -1 NOT NULL,                           
		PREV_REQUEST_CATEGORY_ID INTEGER DEFAULT -1 NOT NULL,                  
		PREV_ITERATION_ID INTEGER DEFAULT -1 NOT NULL,                                              
		PREV_OWNER_ID INTEGER DEFAULT -1 NOT NULL,  
		CHANGE_DATE TIMESTAMP,                                    
		PREV_REQUEST_TYPE VARCHAR (255),                        
		PREV_STATE VARCHAR (255),                             
		PREV_PRIORITY VARCHAR (255),                            
		PREV_SEVERITY VARCHAR (255),                           
		PREV_COMMENT_COUNT INTEGER,                         
		PREV_SUBSCRIBER_COUNT INTEGER,                      
		PREV_TAGS VARCHAR (255),                                 
		PREV_PLANNED_WORK INTEGER,                      
		PREV_ACTUAL_WORK INTEGER,                       
		PREV_STORY_POINTS INTEGER, 
		PREV_SUMMARY VARCHAR (1000),                         
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TIMESHEET (
		TIMESHEET_ID INTEGER NOT NULL,
		TIMESHEET_REPORTING_WEEK DATE,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		ACTIVITY_ID INTEGER DEFAULT -1 NOT NULL,		
		ADDITIONAL_WORK INTEGER,		
		BILLABLE_HOURS INTEGER,		
		NON_BILLABLE_HOURS INTEGER,
		APPROVER_ID INTEGER DEFAULT -1 NOT NULL,
		TIMESHEET_STATE VARCHAR(255),
		PERCENT_COMPLETE DECIMAL(18 , 2),
		LAST_APPROVAL_DATE DATE,
		REGULAR_TIME INTEGER,
		OVERTIME INTEGER,
		MONDAY_DATE DATE,
		TUESDAY_DATE DATE,
		WEDNESDAY_DATE DATE,
		THURSDAY_DATE DATE,
		FRIDAY_DATE DATE,
		SATURDAY_DATE DATE,
		SUNDAY_DATE DATE,
		MONDAY_REGULAR_TIME INTEGER DEFAULT 0,
		TUESDAY_REGULAR_TIME INTEGER DEFAULT 0,
		WEDNESDAY_REGULAR_TIME INTEGER DEFAULT 0,
		THURSDAY_REGULAR_TIME INTEGER DEFAULT 0,
		FRIDAY_REGULAR_TIME INTEGER DEFAULT 0,
		SATURDAY_REGULAR_TIME INTEGER DEFAULT 0,
		SUNDAY_REGULAR_TIME INTEGER DEFAULT 0,
		MONDAY_OVT INTEGER DEFAULT 0,
		TUESDAY_OVT INTEGER DEFAULT 0,
		WEDNESDAY_OVT INTEGER DEFAULT 0,
		THURSDAY_OVT INTEGER DEFAULT 0,
		FRIDAY_OVT INTEGER DEFAULT 0,
		SATURDAY_OVT INTEGER DEFAULT 0,
		SUNDAY_OVT INTEGER DEFAULT 0,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROFILE (
		PROFILE_ID INTEGER NOT NULL,
		NAME VARCHAR(50) DEFAULT 'Profile Name Missing' NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		RATE DECIMAL(18 , 2),
		CREATION_DATE DATE,
		EXPERIENCE_IN_MONTHS INTEGER,
		CITY_ID INTEGER DEFAULT -1 NOT NULL,
		ORGANIZATION_ID INTEGER DEFAULT -1 NOT NULL,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL		
) TABLESPACE VNF_32K ;

CREATE TABLE PROFILE_SKILL_LOOKUP (
		PROFILE_ID INTEGER NOT NULL,
		SKILL_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE PROFILE_COMPETENCY_LOOKUP (
		PROFILE_ID INTEGER NOT NULL,
		COMPETENCY_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE CHARGECODE(
		CHARGECODE_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Charge Code Name Missing' NOT NULL,
		PARENT_CHARGECODE_ID INTEGER DEFAULT -1 NOT NULL,
		CHARGECODE_STATE VARCHAR(255),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TIMECODE(
		TIMECODE_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Charge Code Name Missing' NOT NULL,
		PARENT_TIMECODE_ID INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TIMESHEET_TIMECODE_LOOKUP (
		TIMESHEET_ID INTEGER NOT NULL,
		TIMECODE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

---RTC
CREATE TABLE BUILD_COMPILATION_RESULT	( 
		BUILD_COMPRES_ID INTEGER NOT NULL,                       
		BUILD_ID INTEGER DEFAULT -1 NOT NULL,               
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,          
		COMPILE_ERROR_COUNT INTEGER,   
		COMPILE_WARNING_COUNT INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;
	                        
CREATE TABLE BUILD_UNIT_RESULT	( 
        BUILD_UNITRES_ID INTEGER NOT NULL,	      
		BUILD_ID INTEGER DEFAULT -1 NOT NULL,              
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,           
		UNIT_TEST_COUNT INTEGER,        
		UNIT_FAILURE_COUNT INTEGER,    
		UNIT_ERROR_COUNT INTEGER,
		URL VARCHAR(2048),
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE BUILD_UNIT_EVENT	(                    
		BUILD_UNIT_EVENT_ID INTEGER NOT NULL,	      
		BUILD_ID INTEGER DEFAULT -1 NOT NULL,                 
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,                           
		UNIT_EVENT VARCHAR(255),           
		UNIT_TEST VARCHAR(255),   
		URL VARCHAR(2048),          
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;
   
CREATE TABLE UNIT_TEST_RESULT (	
		UNIT_TEST_RESULT_ID INTEGER NOT NULL,              
		PROJECT_ID INTEGER DEFAULT -1 NOT NULL,               
		TEAM_ID INTEGER DEFAULT -1 NOT NULL,                 
		BUILD_TYPE VARCHAR(255),         
		COMPONENT_ID INTEGER DEFAULT -1 NOT NULL,            
		UNIT_EVENT VARCHAR(255),        
		UNIT_TEST VARCHAR(255),           
		UNIT_COUNT INTEGER, 
		URL VARCHAR(2048),           
		LAST_RUN_DATE TIMESTAMP,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE JOB (
		JOB_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Job Name Missing' NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		PROJECT_ID INTEGER DEFAULT-1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;



CREATE TABLE JOB_RESULT(
		JOB_RESULT_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Job Result Name Missing' NOT NULL,
		STATE VARCHAR(255),
		VERDICT VARCHAR(255), 
		START_TIME TIMESTAMP,
		END_TIME TIMESTAMP,
		DURATION INTEGER,
		LAB_RESOURCE_ID INTEGER DEFAULT -1 NOT NULL,
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		JOB_ID INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TESTSCRIPT(
		TESTSCRIPT_ID INTEGER NOT NULL,
		REFERENCE_ID VARCHAR(50),
		EXTERNAL_ID VARCHAR(100),
		NAME VARCHAR(255) DEFAULT 'Test Script Name Missing' NOT NULL,
		LAST_UPDATED TIMESTAMP,
		TESTSCRIPT_STATE VARCHAR(255),
		TYPE VARCHAR(255),
		OWNER_ID INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		URL VARCHAR(2048),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;


CREATE TABLE M_PROJECT (
		MAP_KEY1 INTEGER,
		MAP_KEY2 VARCHAR(255),
		TARGET_PROJECT_ID INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE M_PRODUCT (
		MAP_KEY1 INTEGER,
		MAP_KEY2 VARCHAR(255),
		TARGET_PRODUCT_ID INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE M_COMPONENT (
		MAP_KEY1 INTEGER,
		MAP_KEY2 VARCHAR(255),
		TARGET_COMPONENT_ID INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE M_ITERATION (
		MAP_KEY1 INTEGER,
		MAP_KEY2 VARCHAR(255),
		TARGET_ITERATION_ID INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE M_RELEASE (
		MAP_KEY1 INTEGER,
		MAP_KEY2 VARCHAR(255),
		TARGET_RELEASE_ID INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE M_RESOURCE (
		MAP_KEY1 INTEGER,
		MAP_KEY2 VARCHAR(255),
		TARGET_RESOURCE_ID INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) TABLESPACE VNF_32K ;

----


CREATE TABLE TEMP_ITERATION  (
		  NAME VARCHAR(256) , 
		  SOURCE_ID VARCHAR(36) )   
 TABLESPACE VNF_32K ;
 

CREATE TABLE TEMP_BUILD  (
		  NAME VARCHAR(256) , 
		  SOURCE_ID VARCHAR(36) )   
 TABLESPACE VNF_32K ;
 

CREATE TABLE TEMP_RELEASE  (
		  NAME VARCHAR(256) , 
		  SOURCE_ID VARCHAR(36) )   
 TABLESPACE VNF_32K ;

CREATE TABLE TEMP_PROJECT
(		PROJECTUNIQUEID VARCHAR(256),
		PROJECTNAME VARCHAR(256),
		PROJECTDATECREATED TIMESTAMP,
		PROJECTHREF VARCHAR(2048),
		COMPONENTUNIQUEID VARCHAR(256),
		STREAMUNIQUEID VARCHAR(256),
		STREAMNAME VARCHAR(256),
		STREAMHREF VARCHAR(2048),
		ACTIVITYUNIQUEID VARCHAR(256),
		ACTIVITYNAME VARCHAR(256),
		ACTIVITYOWNER VARCHAR(256),
		ACTIVITYSTATE VARCHAR(256),
		ACTIVITYDATECREATED TIMESTAMP,
		ACTIVITYHREF VARCHAR(2048),
		VERSIONUNIQUEID VARCHAR(256),
		DATASOURCE_ID VARCHAR(36)
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_REQUEST_HISTORY
	(
	HISTORY_DBID INTEGER,
	HISTORY_UUID_DBID VARCHAR(256),
	HISTORY_ACTION_TIMESTAMP TIMESTAMP,
	DATASOURCE_ID VARCHAR(36),
	HISTORY_OLD_STATE VARCHAR(256),
	HISTORY_NEW_STATE VARCHAR(256),
	DBID INTEGER,
	DBID_UUID VARCHAR(256)
	) TABLESPACE VNF_32K ;
	
CREATE TABLE TEMP_TEST_CATEGORY
	(
	CATEGORY_VALUE VARCHAR(255),
	CATEGORY_TERM VARCHAR(255),
	DATASOURCE_ID VARCHAR(36)
	) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_ACTIVITY_HISTORY
	(
	HISTORY_DBID INTEGER,
	HISTORY_ACTION_TIMESTAMP TIMESTAMP,
	DATASOURCE_ID VARCHAR(36),
	HISTORY_OLD_STATE VARCHAR(256),
	HISTORY_NEW_STATE VARCHAR(256),
	DBID INTEGER
	) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_TASK_HISTORY
	(
	HISTORY_DBID INTEGER,
	HISTORY_ACTION_TIMESTAMP TIMESTAMP,
	DATASOURCE_ID VARCHAR(36),
	HISTORY_OLD_STATE VARCHAR(256),
	HISTORY_NEW_STATE VARCHAR(256),
	DBID INTEGER
	) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_FILEVERSION 
(		CREATEDBY VARCHAR(256),
		DATECREATED TIMESTAMP,
		VERSIONNUMBER VARCHAR(256),
		LINESOFCODE INTEGER,
		BRANCH  VARCHAR(256),
		UNIQUEID  VARCHAR(256),
		CHANGESFROMPREDECESSOR INTEGER,
		FILEELEMENTUNIQUEID VARCHAR(256),
		FILEELEMENTNAME VARCHAR(256),
		DATASOURCE_ID VARCHAR(36)
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_COMPONENT
(		COMPONENTNAME VARCHAR(256),
		COMPONENTUNIQUEID VARCHAR(256),
		COMPONENTHREF VARCHAR(2048),
		FILEELEMENTUNIQUEID VARCHAR(256),
		BASELINENAME VARCHAR(256),
		BASELINEUNIQUEID VARCHAR(256),
		BASELINEHREF VARCHAR(2048),
		BASELINEACTIVITIESUNIQUEID VARCHAR(256),
		DATASOURCE_ID VARCHAR(36)
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_BASELINE (
		BASELINE_ID VARCHAR(256),
		NAME VARCHAR(256),
		BASELINE_DATE TIMESTAMP,
		PARENT_ID VARCHAR(256),
		PARENT_TITLE VARCHAR(256),
		PLANNED_SCHEDULE_ID VARCHAR(256),
		PLANNED_START DATE,
		PLANNED_FINISH DATE,
		PLANNED_WORK INTEGER,
		PLANNED_COST DECIMAL(18 , 2),
		PLANNED_DURATION INTEGER,
		URL VARCHAR(2048),
		DATASOURCE_ID VARCHAR(36)
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_CALENDAR  (
		  IDREF CHAR(40) NOT NULL , 
		  ADOPTED_CALENDAR CHAR(40) , 
		  USER_IDREF CHAR(40) , 
		  SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		  HOURSPERDAY DECIMAL(5,2) 
) TABLESPACE VNF_32K ; 

CREATE TABLE TEMP_PROJECT_CALENDAR (
		  PROJECT_IDREF CHAR(40) NOT NULL , 
		  CALENDAR_IDREF CHAR(40) NOT NULL 
) TABLESPACE VNF_32K ; 

CREATE TABLE TEMP_RESOURCE_CALENDAR (
		  RESOURCE_ID INTEGER NOT NULL , 
		  MINUTES_PER_DAY INTEGER NOT NULL 
) TABLESPACE VNF_32K ; 

CREATE TABLE TEMP_CAL_EXCEPTION_RANGE (
	  FROMDATE DATE , 
	  TODATE DATE , 
	  HOURSBLOCKED DECIMAL(5,2) , 
		EXCEPTIONTYPE VARCHAR(255),
		DAYOFWEEK VARCHAR(255),
		DURATION INTEGER,
		EFFORT INTEGER,
	  IDREF CHAR(40) , 
	  CALENDAR_IDREF CHAR(40) , 
	  DAYOFMONTH INTEGER , 
	  MONTHOFYEAR INTEGER,
	  SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP 
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_RESOURCE_CALENDAR_EXCEP(
		RESOURCE_ID INTEGER NOT NULL,
		EXCEPTION_DATE DATE NOT NULL,
		EXCEPTION_MINUTES INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_PROJECT_CALENDAR_EXCEP(
		PROJECT_ID INTEGER NOT NULL,
		EXCEPTION_DATE DATE NOT NULL,
		EXCEPTION_MINUTES INTEGER NOT NULL,
		EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,
		SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE TEMP_POOL_HIERARCHY  (
		POOL_ID INTEGER NOT NULL , 
		"LEVEL" INTEGER NOT NULL 
) TABLESPACE VNF_32K ; 

CREATE TABLE TEMP_REQUIREMENT(
	    CREATED_ON DATE,
		CREATED_BY VARCHAR (255),
		REQUIREMENT_NAME VARCHAR (255),
		IDENTIFIER VARCHAR (255),
		LAST_MODIFIED_ON DATE,
		COMPONENT VARCHAR (255),
		DIFFICULTY VARCHAR (255),
		REQUIREMENT_TYPE VARCHAR (255),
		ACTUAL_ITERATION VARCHAR (255),
		CUSTOMER_PRIORITY VARCHAR (255),
		PLANNED_ITERATION VARCHAR (255),
		PLATFORM VARCHAR (255),
		PRIORITY VARCHAR (255),
		PROJECT_ID VARCHAR (255),
		STABILITY VARCHAR (255),
		STATE VARCHAR (255),
		STATUS VARCHAR (255),
		URL VARCHAR (255),
		DATASOURCE_ID VARCHAR (255),
		CHILD_ID INTEGER,
		PARENT_ID  INTEGER,
		SOURCE_ID VARCHAR (255),
		TARGET_ID  INTEGER
) TABLESPACE VNF_32K;	

-- INDEXES

CREATE INDEX ACTI_IDX1 ON ACTIVITY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASETR_IDX1 ON ASSETREGISTRY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX BUILD_IDX1 ON BUILD (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMMENT_IDX1 ON "COMMENT" (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPONENT_IDX1 ON COMPONENT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPTEAM_IDX1 ON TEAM (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIG_IDX1 ON CONFIGURATION (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIGATT_IDX1 ON CONFIGURATION_ATTRIBUTE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECWKI_TSTC_IDX1 ON EXECUTION_WORKITEM (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CURRENCY_IDX1 ON CURRENCY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CUSTOMER_IDX1 ON CUSTOMER (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FACTOR_IDX1 ON FACTOR (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILE_IDX1 ON "FILE" (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILESTR_IDX1 ON FILE_STREAM (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILEVER_IDX1 ON FILE_VERSION (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERATION_IDX1 ON ITERATION (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX POOL_IDX1 ON POOL (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PRODUCT_IDX1 ON PRODUCT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJECT_IDX1 ON PROJECT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJBASE_IDX1 ON PROJECT_BASELINE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJCAT_IDX1 ON PROJECT_CATEGORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PHASE_IDX1 ON PHASE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJROLE_IDX1 ON PROJECT_ROLE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJTYPE_IDX1 ON PROJECT_TYPE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJWRKCFG_IDX1 ON PROJECT_WORKCONFIGURATION (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RELEASE_IDX1 ON RELEASE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX1 ON REQUEST (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQSTH_IDX1 ON REQUEST_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX1 ON REQUIREMENT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESOURCE_IDX1 ON "RESOURCE" (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISK_IDX1 ON RISK (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISKSTH_IDX1 ON RISK_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITELOG_IDX1 ON TESTSUITELOG (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX1 ON TASK (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASKCAT_IDX1 ON TASK_CATEGORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTCASE_IDX1 ON TESTCASE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECRES_IDX1 ON EXECUTION_RESULT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTPLAN_IDX1 ON TESTPLAN (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITE_IDX1 ON TESTSUITE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTTYPE_IDX1 ON TESTTYPE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LABRES_IDX1 ON LAB_RESOURCE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESGRP_IDX1 ON RESOURCE_GROUP (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESERV_IDX1 ON RESERVATION (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTSTH_IDX1 ON ACTIVITY_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TSKSTH_IDX1 ON TASK_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOB_IDX1 ON JOB (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOBRES_IDX1 ON JOB_RESULT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSCRIPT_IDX1 ON TESTSCRIPT (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX ACTI_IDX2 ON ACTIVITY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASETR_IDX2 ON ASSETREGISTRY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX BUILD_IDX2 ON BUILD (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMMENT_IDX2 ON "COMMENT" (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPONENT_IDX2 ON COMPONENT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPTEAM_IDX2 ON TEAM (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIG_IDX2 ON CONFIGURATION (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIGATT_IDX2 ON CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECWKI_TSTC_IDX2 ON EXECUTION_WORKITEM (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CURRENCY_IDX2 ON CURRENCY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CUSTOMER_IDX2 ON CUSTOMER (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FACTOR_IDX2 ON FACTOR (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILE_IDX2 ON "FILE" (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILESTR_IDX2 ON FILE_STREAM (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILEVER_IDX2 ON FILE_VERSION (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERATION_IDX2 ON ITERATION (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX POOL_IDX2 ON POOL (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PRODUCT_IDX2 ON PRODUCT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJECT_IDX2 ON PROJECT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJBASE_IDX2 ON PROJECT_BASELINE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJCAT_IDX2 ON PROJECT_CATEGORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PHASE_IDX2 ON PHASE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJROLE_IDX2 ON PROJECT_ROLE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJTYPE_IDX2 ON PROJECT_TYPE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJWRKCFG_IDX2 ON PROJECT_WORKCONFIGURATION (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RELEASE_IDX2 ON RELEASE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX2 ON REQUEST (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQSTH_IDX2 ON REQUEST_STATE_HISTORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX2 ON REQUIREMENT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESOURCE_IDX2 ON "RESOURCE" (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISK_IDX2 ON RISK (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISKSTH_IDX2 ON RISK_STATE_HISTORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITELOG_IDX2 ON TESTSUITELOG (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX2 ON TASK (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASKCAT_IDX2 ON TASK_CATEGORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTCASE_IDX2 ON TESTCASE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECRES_IDX2 ON EXECUTION_RESULT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTPLAN_IDX2 ON TESTPLAN (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITE_IDX2 ON TESTSUITE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTTYPE_IDX2 ON TESTTYPE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LABRES_IDX2 ON LAB_RESOURCE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESGRP_IDX2 ON RESOURCE_GROUP (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESERV_IDX2 ON RESERVATION (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTSTH_IDX2 ON ACTIVITY_STATE_HISTORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TSKSTH_IDX2 ON TASK_STATE_HISTORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOB_IDX2 ON JOB (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOBRES_IDX2 ON JOB_RESULT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSCRIPT_IDX2 ON TESTSCRIPT (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX ACTI_IDX3 ON ACTIVITY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASETR_IDX3 ON ASSETREGISTRY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX BUILD_IDX3 ON BUILD (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMMENT_IDX3 ON "COMMENT" (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPONENT_IDX3 ON COMPONENT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPTEAM_IDX3 ON TEAM (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIG_IDX3 ON CONFIGURATION (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIGATT_IDX3 ON CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECWKI_TSTC_IDX3 ON EXECUTION_WORKITEM (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CURRENCY_IDX3 ON CURRENCY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CUSTOMER_IDX3 ON CUSTOMER (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FACTOR_IDX3 ON FACTOR (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILE_IDX3 ON "FILE" (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILESTR_IDX3 ON FILE_STREAM (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILEVER_IDX3 ON FILE_VERSION (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERATION_IDX3 ON ITERATION (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX POOL_IDX3 ON POOL (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PRODUCT_IDX3 ON PRODUCT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJECT_IDX3 ON PROJECT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJBASE_IDX3 ON PROJECT_BASELINE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJCAT_IDX3 ON PROJECT_CATEGORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PHASE_IDX3 ON PHASE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJROLE_IDX3 ON PROJECT_ROLE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJTYPE_IDX3 ON PROJECT_TYPE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJWRKCFG_IDX3 ON PROJECT_WORKCONFIGURATION (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RELEASE_IDX3 ON RELEASE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX3 ON REQUEST (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQSTH_IDX3 ON REQUEST_STATE_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX3 ON REQUIREMENT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESOURCE_IDX3 ON "RESOURCE" (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISK_IDX3 ON RISK (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISKSTH_IDX3 ON RISK_STATE_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITELOG_IDX3 ON TESTSUITELOG (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX3 ON TASK (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASKCAT_IDX3 ON TASK_CATEGORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTCASE_IDX3 ON TESTCASE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECRES_IDX3 ON EXECUTION_RESULT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTPLAN_IDX3 ON TESTPLAN (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITE_IDX3 ON TESTSUITE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTTYPE_IDX3 ON TESTTYPE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LABRES_IDX3 ON LAB_RESOURCE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESGRP_IDX3 ON RESOURCE_GROUP (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESERV_IDX3 ON RESERVATION (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTSTH_IDX3 ON ACTIVITY_STATE_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TSKSTH_IDX3 ON TASK_STATE_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOB_IDX3 ON JOB (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOBRES_IDX3 ON JOB_RESULT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSCRIPT_IDX3 ON TESTSCRIPT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;

 
CREATE INDEX ACTI_IDX4 ON ACTIVITY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASETR_IDX4 ON ASSETREGISTRY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX BUILD_IDX4 ON BUILD (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMMENT_IDX4 ON "COMMENT" (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPONENT_IDX4 ON COMPONENT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPTEAM_IDX4 ON TEAM (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIG_IDX4 ON CONFIGURATION (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIGATT_IDX4 ON CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECWKI_TSTC_IDX4 ON EXECUTION_WORKITEM (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CURRENCY_IDX4 ON CURRENCY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CUSTOMER_IDX4 ON CUSTOMER (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FACTOR_IDX4 ON FACTOR (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILE_IDX4 ON "FILE" (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILESTR_IDX4 ON FILE_STREAM (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILEVER_IDX4 ON FILE_VERSION (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERATION_IDX4 ON ITERATION (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX POOL_IDX4 ON POOL (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PRODUCT_IDX4 ON PRODUCT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJECT_IDX4 ON PROJECT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJBASE_IDX4 ON PROJECT_BASELINE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJCAT_IDX4 ON PROJECT_CATEGORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PHASE_IDX4 ON PHASE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJROLE_IDX4 ON PROJECT_ROLE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJTYPE_IDX4 ON PROJECT_TYPE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJWRKCFG_IDX4 ON PROJECT_WORKCONFIGURATION (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RELEASE_IDX4 ON RELEASE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX4 ON REQUEST (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQSTH_IDX4 ON REQUEST_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX4 ON REQUIREMENT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESOURCE_IDX4 ON "RESOURCE" (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISK_IDX4 ON RISK (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISKSTH_IDX4 ON RISK_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITELOG_IDX4 ON TESTSUITELOG (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX4 ON TASK (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASKCAT_IDX4 ON TASK_CATEGORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTCASE_IDX4 ON TESTCASE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECRES_IDX4 ON EXECUTION_RESULT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTPLAN_IDX4 ON TESTPLAN (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITE_IDX4 ON TESTSUITE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTTYPE_IDX4 ON TESTTYPE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LABRES_IDX4 ON LAB_RESOURCE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESGRP_IDX4 ON RESOURCE_GROUP (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESERV_IDX4 ON RESERVATION (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTSTH_IDX4 ON ACTIVITY_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TSKSTH_IDX4 ON TASK_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOB_IDX4 ON JOB (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOBRES_IDX4 ON JOB_RESULT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSCRIPT_IDX4 ON TESTSCRIPT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;


CREATE INDEX ACTI_IDX5 ON ACTIVITY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASETR_IDX5 ON ASSETREGISTRY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX BUILD_IDX5 ON BUILD (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMMENT_IDX5 ON "COMMENT" (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPONENT_IDX5 ON COMPONENT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPTEAM_IDX5 ON TEAM (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIG_IDX5 ON CONFIGURATION (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CONFIGATT_IDX5 ON CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECWKI_TSTC_IDX5 ON EXECUTION_WORKITEM (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CURRENCY_IDX5 ON CURRENCY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CUSTOMER_IDX5 ON CUSTOMER (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FACTOR_IDX5 ON FACTOR (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILE_IDX5 ON "FILE" (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILESTR_IDX5 ON FILE_STREAM (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILEVER_IDX5 ON FILE_VERSION (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERATION_IDX5 ON ITERATION (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX POOL_IDX5 ON POOL (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PRODUCT_IDX5 ON PRODUCT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJECT_IDX5 ON PROJECT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJBASE_IDX5 ON PROJECT_BASELINE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJCAT_IDX5 ON PROJECT_CATEGORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PHASE_IDX5 ON PHASE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJROLE_IDX5 ON PROJECT_ROLE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJTYPE_IDX5 ON PROJECT_TYPE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJWRKCFG_IDX5 ON PROJECT_WORKCONFIGURATION (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RELEASE_IDX5 ON RELEASE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX5 ON REQUEST (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQSTH_IDX5 ON REQUEST_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX5 ON REQUIREMENT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESOURCE_IDX5 ON "RESOURCE" (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISK_IDX5 ON RISK (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RISKSTH_IDX5 ON RISK_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITELOG_IDX5 ON TESTSUITELOG (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX5 ON TASK (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASKCAT_IDX5 ON TASK_CATEGORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTCASE_IDX5 ON TESTCASE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECRES_IDX5 ON EXECUTION_RESULT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTPLAN_IDX5 ON TESTPLAN (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSUITE_IDX5 ON TESTSUITE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTTYPE_IDX5 ON TESTTYPE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LABRES_IDX5 ON LAB_RESOURCE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESGRP_IDX5 ON RESOURCE_GROUP (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX RESERV_IDX5 ON RESERVATION (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTSTH_IDX5 ON ACTIVITY_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TSKSTH_IDX5 ON TASK_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOB_IDX5 ON JOB (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX JOBRES_IDX5 ON JOB_RESULT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSCRIPT_IDX5 ON TESTSCRIPT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX REQUEST_IDX6 ON REQUEST (ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX7 ON REQUEST (REQUEST_CLASS_ID ,REQUEST_ID ,EXTERNAL_KEY1 ,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX15 ON REQUEST (REQUEST_CLASS_ID ,REQUEST_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX8 ON REQUEST (REQUEST_ID ,EXTERNAL_KEY1 ,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX9 ON REQUEST (BUILD_ID ,REQUEST_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX10 ON REQUEST (REQUEST_CLASS_ID ,PROJECT_ID ,COMPONENT_ID ,OWNER_ID ,REQUEST_ID ,ITERATION_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX11 ON REQUEST (REQUEST_SOURCE) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX12 ON REQUEST (REQUEST_TYPE) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX13 ON REQUEST (STATUS) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUEST_IDX14 ON REQUEST (COMPONENT_ID ,IS_BLOCKING ,REQUEST_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX6 ON REQUIREMENT (ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX7 ON REQUIREMENT (SOURCE_ID ,ISSOFTDELETED ,REQUIREMENT_ID ) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX REQUI_IDX8 ON REQUIREMENT (REQUIREMENT_CLASS_ID ,PROJECT_ID,COMPONENT_ID ,PLANNED_ITERATION_ID ,RELEASE_ID ,REQUIREMENT_ID ,OWNER_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FILEVER_IDX6 ON FILE_VERSION (FILE_ID ,FILE_VERSION_ID ,ACTIVITY_ID ,FILE_STREAM_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX6 ON TASK (ITERATION_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_IDX7 ON TASK (TASK_TYPE) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TMPHISREQ_IDX1 ON TEMP_REQUEST_HISTORY (DBID ,DATASOURCE_ID ,HISTORY_ACTION_TIMESTAMP) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TMPHISREQ_IDX2 ON REQUEST_STATE_HISTORY (DAYS_IN_STATE ,REQUEST_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TMPHISREQ_IDX3 ON TEMP_REQUEST_HISTORY (HISTORY_OLD_STATE ,HISTORY_DBID ,HISTORY_NEW_STATE ,DBID ,DATASOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX FBASELNACT_IDX1 ON FILE_BASELINE_ACTIVITY_LOOKUP (ACTIVITY_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TMPHISREQ_IDX4 ON TEMP_REQUEST_HISTORY (HISTORY_NEW_STATE ,HISTORY_OLD_STATE ,DBID ,DATASOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TMPHISREQ_IDX5 ON REQUEST_CHANGE_HISTORY (REQUEST_ID ,CHANGE_DATE) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTI_IDX6 ON ACTIVITY (ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTI_IDX7 ON ACTIVITY (OWNER_ID ,ACTIVITY_ID ,ACTIVITY_CLASS_ID ,TASK_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTI_IDX8 ON ACTIVITY (ACTIVITY_CLASS_ID ,OWNER_ID ,ACTIVITY_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ACTI_IDX9 ON ACTIVITY (SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX EXECWKI_IDX6 ON EXECUTION_WORKITEM (SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJECT_IDX6 ON PROJECT (ISSOFTDELETED ) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX BUILD_IDX6 ON BUILD (ISSOFTDELETED ) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TESTSCRIPT_IDX6 ON TESTSCRIPT (ISSOFTDELETED ) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX CITY_IDX1 ON CITY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CITY_IDX2 ON CITY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX; 
CREATE INDEX CITY_IDX3 ON CITY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CITY_IDX4 ON CITY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;  
CREATE INDEX CITY_IDX5 ON CITY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX; 

CREATE INDEX COMPETENCY_IDX1 ON COMPETENCY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPETENCY_IDX2 ON COMPETENCY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX COMPETENCY_IDX3 ON COMPETENCY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX COMPETENCY_IDX4 ON COMPETENCY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COMPETENCY_IDX5 ON COMPETENCY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX COUNTRY_IDX1 ON COUNTRY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COUNTRY_IDX2 ON COUNTRY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX COUNTRY_IDX3 ON COUNTRY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX COUNTRY_IDX4 ON COUNTRY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX COUNTRY_IDX5 ON COUNTRY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX ITERBASELINE_IDX1 ON ITERATION_BASELINE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERBASELINE_IDX2 ON ITERATION_BASELINE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX ITERBASELINE_IDX3 ON ITERATION_BASELINE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX ITERBASELINE_IDX4 ON ITERATION_BASELINE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ITERBASELINE_IDX5 ON ITERATION_BASELINE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX OPERTERRI_IDX1 ON OPERATING_TERRITORY (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;   
CREATE INDEX OPERTERRI_IDX2 ON OPERATING_TERRITORY (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX OPERTERRI_IDX3 ON OPERATING_TERRITORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX OPERTERRI_IDX4 ON OPERATING_TERRITORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX OPERTERRI_IDX5 ON OPERATING_TERRITORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX PROGRAM_IDX1 ON PROGRAM (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROGRAM_IDX2 ON PROGRAM (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX PROGRAM_IDX3 ON PROGRAM (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX PROGRAM_IDX4 ON PROGRAM (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROGRAM_IDX5 ON PROGRAM (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX PROJALLOC_IDX1 ON PROJECT_ALLOCATION (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJALLOC_IDX2 ON PROJECT_ALLOCATION (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX PROJALLOC_IDX3 ON PROJECT_ALLOCATION (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX PROJALLOC_IDX4 ON PROJECT_ALLOCATION (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROJALLOC_IDX5 ON PROJECT_ALLOCATION (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX PROVSTATE_IDX1 ON PROVINCE_STATE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROVSTATE_IDX2 ON PROVINCE_STATE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX PROVSTATE_IDX3 ON PROVINCE_STATE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX PROVSTATE_IDX4 ON PROVINCE_STATE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX PROVSTATE_IDX5 ON PROVINCE_STATE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX SKILL_IDX1 ON SKILL (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX SKILL_IDX2 ON SKILL (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX SKILL_IDX3 ON SKILL (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX SKILL_IDX4 ON SKILL (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX SKILL_IDX5 ON SKILL (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX TASK_BASE_IDX1 ON TASK_BASELINE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;     
CREATE INDEX TASK_BASE_IDX2 ON TASK_BASELINE (EXTERNAL_KEY1) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX TASK_BASE_IDX3 ON TASK_BASELINE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;          
CREATE INDEX TASK_BASE_IDX4 ON TASK_BASELINE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX TASK_BASE_IDX5 ON TASK_BASELINE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX CHARGECODE_IDX1 ON CHARGECODE (SOURCE_ID,ISSOFTDELETED) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CHARGECODE_IDX2 ON CHARGECODE (EXTERNAL_KEY1)  REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CHARGECODE_IDX3 ON CHARGECODE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CHARGECODE_IDX4 ON CHARGECODE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX CHARGECODE_IDX5 ON CHARGECODE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;



-- PRIMARY KEY CONSTRAINTS
ALTER TABLE CUSTOMER ADD CONSTRAINT CUSTOMER_PK PRIMARY KEY (CUSTOMER_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ACTIVITY_CLASSIFICATION ADD CONSTRAINT ACTIVITYCL_PK PRIMARY KEY (ACTIVITY_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_PK PRIMARY KEY (ACTIVITY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_PK PRIMARY KEY (REQUEST_ID,ACTIVITY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE COMPONENT ADD CONSTRAINT COMPONENT_PK PRIMARY KEY (COMPONENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_PK PRIMARY KEY (PROJECT_ID,COMPONENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE COMPONENT_CLASSIFICATION ADD CONSTRAINT COMPCLS_PK PRIMARY KEY (COMPONENT_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;
	
ALTER TABLE BUILD ADD CONSTRAINT BUILD_PK PRIMARY KEY (BUILD_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_PK PRIMARY KEY (REQUIREMENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_PK PRIMARY KEY (REQUIREMENT_REVISION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITE ADD CONSTRAINT TESTSUITE_PK PRIMARY KEY (TESTSUITE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_PK PRIMARY KEY (EXECUTION_RESULT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CURRENCY ADD CONSTRAINT CURRENCY_PK PRIMARY KEY (CURRENCY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE POOL ADD CONSTRAINT POOL_PK PRIMARY KEY (POOL_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE "RESOURCE" ADD CONSTRAINT RESOURCE_PK PRIMARY KEY (RESOURCE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE SKILL ADD CONSTRAINT SKILL_PK PRIMARY KEY(SKILL_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RESOURCE_SKILL_LOOKUP ADD CONSTRAINT RESSKILL_PK PRIMARY KEY(RESOURCE_ID, SKILL_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE COMPETENCY ADD CONSTRAINT COMPETENCY_PK PRIMARY KEY(COMPETENCY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RESOURCE_COMPETENCY_LOOKUP ADD CONSTRAINT RESCOMPETENCY_PK PRIMARY KEY(RESOURCE_ID, COMPETENCY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_STATE_HISTORY ADD CONSTRAINT REQUESTSTATEHIS_PK PRIMARY KEY (REQUEST_STATE_HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_CLASSIFICATION ADD CONSTRAINT REQ_CATEGORY_PK PRIMARY KEY (REQUEST_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_CLASSIFICATION ADD CONSTRAINT REQUI_CATG_PK PRIMARY KEY (REQUIREMENT_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_CATEGORY ADD CONSTRAINT TASK_CATEGORY_PK PRIMARY KEY (TASK_CATEGORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PRODUCT ADD CONSTRAINT PRODUCT_PK PRIMARY KEY (PRODUCT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ASSETREGISTRY ADD CONSTRAINT ASSETREGISTRY_PK PRIMARY KEY (ASSETREGISTRY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ITERATION ADD CONSTRAINT ITERATION_PK PRIMARY KEY (ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ITERATION_BASELINE ADD CONSTRAINT ITERBASELINE_PK PRIMARY KEY (BASELINE_ID,ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RELEASE ADD CONSTRAINT RELEASE_PK PRIMARY KEY (RELEASE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_CLASSIFICATION ADD CONSTRAINT PROJECTCL_PK PRIMARY KEY (PROJECT_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT ADD CONSTRAINT PROJECT_PK PRIMARY KEY (PROJECT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_BASELINE ADD CONSTRAINT TASKBL_PK PRIMARY KEY (BASELINE_ID,TASK_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_CLASSIFICATION ADD CONSTRAINT TASKCL_PK PRIMARY KEY (TASK_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK ADD CONSTRAINT TASK_PK PRIMARY KEY (TASK_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_PK PRIMARY KEY (PARENT_PROJECT_ID, CHILD_PROJECT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_DETAIL ADD CONSTRAINT PROJECTDT_PK PRIMARY KEY (PROJECT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_TYPE ADD CONSTRAINT PRJTYPE_PK PRIMARY KEY (PROJECT_TYPE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_PK PRIMARY KEY (PROJECT_WKCFG_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_CATEGORY ADD CONSTRAINT PRJCAT_PK PRIMARY KEY (PROJECT_CATEGORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PHASE ADD CONSTRAINT PRJPHASE_PK PRIMARY KEY (PHASE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_ROLE ADD CONSTRAINT PRJROLE_PK PRIMARY KEY (PROJECT_ROLE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_PK PRIMARY KEY (PROJECT_ROLE_ID, RESOURCE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TEAM ADD CONSTRAINT CMPTEAM_PK PRIMARY KEY (TEAM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_DETAIL ADD CONSTRAINT TASKDT_PK PRIMARY KEY (TASK_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_PK PRIMARY KEY (TASK_ID, REQUIREMENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CONFIGURATION ADD CONSTRAINT CONFIGURATION_PK PRIMARY KEY (CONFIGURATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CONFIGURATION_ATTRIBUTE ADD CONSTRAINT CFG_ATTRIBUTE_PK PRIMARY KEY (CONFIGURATION_ATTRIBUTE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_PK PRIMARY KEY (CONFIGURATION_ATTRIBUTE_ID, CONFIGURATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_PK PRIMARY KEY (TESTSUITE_ID, ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTPLAN ADD CONSTRAINT TESTPLAN_PK PRIMARY KEY (TESTPLAN_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_PK PRIMARY KEY (TESTPLAN_ID, ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTTYPE ADD CONSTRAINT TESTTYPE_PK PRIMARY KEY (TESTTYPE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTCASE ADD CONSTRAINT TESTCASE_PK PRIMARY KEY (TESTCASE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_PK PRIMARY KEY (TESTCASE_ID, ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_PK PRIMARY KEY (REQUIREMENT_ID, TESTCASE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_PK PRIMARY KEY (REQUIREMENT_ID, TESTPLAN_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_PK PRIMARY KEY (REQUIREMENT_ID, TESTSUITE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_PK PRIMARY KEY (REQUIREMENT_ID, CREQUIREMENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_PK PRIMARY KEY (PRED_REQUIREMENT_ID, SUCC_REQUIREMENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_PK PRIMARY KEY (EXECWORKITEM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXWKIITER_PK PRIMARY KEY (EXECWORKITEM_ID, ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXWKI_PK PRIMARY KEY (REQUIREMENT_ID, EXECWORKITEM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXWKITSU_PK PRIMARY KEY (EXECWORKITEM_ID, TESTSUITE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_PK PRIMARY KEY (REQUEST_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_PK PRIMARY KEY (PARENT_REQUEST_ID, CHILD_REQUEST_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FILE_VERSION ADD CONSTRAINT FLVERSION_PK PRIMARY KEY (FILE_VERSION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE "FILE" ADD CONSTRAINT FILE_PK PRIMARY KEY (FILE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FILE_BASELINE ADD CONSTRAINT FBASELINE_PK PRIMARY KEY (FILE_BASELINE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_PK PRIMARY KEY (FILE_BASELINE_ID,ACTIVITY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FILE_STREAM ADD CONSTRAINT FSTREAM_PK PRIMARY KEY (FILE_STREAM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT EXWKISLG_PK PRIMARY KEY (CONFIGURATION_ID, EXECUTION_RESULT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_PK PRIMARY KEY (TESTSUITELOG_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_PK PRIMARY KEY (TESTSUITELOG_ID, EXECUTION_RESULT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISS_PK PRIMARY KEY (TASK_ID, REQUEST_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQIREQ_PK PRIMARY KEY (REQUIREMENT_ID, REQUEST_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_PK PRIMARY KEY (REQUEST_ID, CUSTOMER_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_PK PRIMARY KEY (REQUIREMENT_ID, CUSTOMER_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRGREQ_PK PRIMARY KEY (REQUEST_ID, EXECUTION_RESULT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RISK ADD CONSTRAINT RISK_PK PRIMARY KEY (RISK_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RISK_STATE_HISTORY ADD CONSTRAINT RISKSTATEHIS_PK PRIMARY KEY (RISK_STATE_HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FACTOR ADD CONSTRAINT FACTOR_PK PRIMARY KEY (FACTOR_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_PK PRIMARY KEY (BASELINE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_PK PRIMARY KEY (BASELINE_ID, COMPBASELINE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE "COMMENT" ADD CONSTRAINT COMMENT_PK PRIMARY KEY (COMMENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ACTIVITY_DETAIL ADD CONSTRAINT ACTIVITY_DETAIL_PK PRIMARY KEY (ACTIVITY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_PK PRIMARY KEY(PARENT_WKCFG_ID,CHILD_WKCFG_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TEST_CATEGORY ADD CONSTRAINT TSTCAT_PK PRIMARY KEY (TEST_CATEGORY_ID) USING INDEX TABLESPACE  VNF_IDX;	

ALTER TABLE EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_PK PRIMARY KEY (EXECUTION_RESULT_ID,EXECWORKITEM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_PK PRIMARY KEY (CONFIGURATION_ID,EXECWORKITEM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_PK PRIMARY KEY (TEST_CATEGORY_ID,TESTPLAN_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_PK PRIMARY KEY (TEST_CATEGORY_ID,TESTCASE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_PK PRIMARY KEY (TESTCASE_ID,TESTSUITE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_PK PRIMARY KEY (TESTSUITE_ID,TESTSUITELOG_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_PK PRIMARY KEY (PARENT_TESTPLAN_ID,CHILD_TESTPLAN_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_PK PRIMARY KEY (TESTPLAN_ID,TESTCASE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE LAB_RESOURCE ADD CONSTRAINT LABRES_PK PRIMARY KEY (LAB_RESOURCE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RESOURCE_GROUP ADD CONSTRAINT RESGRP_PK PRIMARY KEY (RESOURCE_GROUP_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE RESERVATION ADD CONSTRAINT RESERV_PK PRIMARY KEY (RESERVATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTCASE_CLASSIFICATION ADD CONSTRAINT TCCLASS_PK PRIMARY KEY (TESTCASE_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTPLAN_CLASSIFICATION ADD CONSTRAINT TPLCLASS_PK PRIMARY KEY (TESTPLAN_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITE_CLASSIFICATION ADD CONSTRAINT TSUCLASS_PK PRIMARY KEY (TESTSUITE_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTSUITELOG_CLASSIFICATION ADD CONSTRAINT  TSLCLASS_PK PRIMARY KEY (TESTSUITELOG_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECRESULT_CLASSIFICATION ADD CONSTRAINT EXRESCLASS_PK PRIMARY KEY (EXECRES_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE EXECWORKITEM_CLASSIFICATION ADD CONSTRAINT EXEWKITCLASS_PK PRIMARY KEY (EXECWORKIT_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CONFIGURATION_CLASSIFICATION ADD CONSTRAINT CONFIGCLASS_PK PRIMARY KEY (CONFIGURATION_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ACTIVITY_STATE_HISTORY ADD CONSTRAINT ACTSTH_PK PRIMARY KEY (ACTIVITY_STATE_HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TASK_STATE_HISTORY ADD CONSTRAINT TSKSTH_PK PRIMARY KEY (TASK_STATE_HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_CATEGORY ADD CONSTRAINT REQCAT_PK PRIMARY KEY (REQUEST_CATEGORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FILE_CLASSIFICATION ADD CONSTRAINT FILECLS_PK PRIMARY KEY (FILE_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE FILE_STREAM_CLASSIFICATION ADD CONSTRAINT FILESTRMCLS_PK PRIMARY KEY (FILE_STREAM_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_PK PRIMARY KEY (REQCHANGE_HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE BUILD_CLASSIFICATION  ADD CONSTRAINT BLDCLS_PK PRIMARY KEY (BUILD_CLASS_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_PK PRIMARY KEY (BUILD_COMPRES_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_PK PRIMARY KEY (BUILD_UNITRES_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_PK PRIMARY KEY (BUILD_UNIT_EVENT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_PK PRIMARY KEY (UNIT_TEST_RESULT_ID) USING INDEX TABLESPACE  VNF_IDX;	

ALTER TABLE JOB ADD CONSTRAINT JOB_PK PRIMARY KEY (JOB_ID) USING INDEX TABLESPACE  VNF_IDX;	

ALTER TABLE JOB_RESULT ADD CONSTRAINT JOBRES_PK PRIMARY KEY (JOB_RESULT_ID) USING INDEX TABLESPACE  VNF_IDX;	

ALTER TABLE TESTSCRIPT ADD CONSTRAINT TESTSCRIPT_PK PRIMARY KEY (TESTSCRIPT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TESTCASE_TESTSCRIPT_LOOKUP ADD CONSTRAINT TESTCSCRIPT_PK PRIMARY KEY (TESTCASE_ID,TESTSCRIPT_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ITERATION_DETAIL ADD CONSTRAINT ITERDET_PK PRIMARY KEY (ITERATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROGRAM ADD CONSTRAINT PROGRAM_PK PRIMARY KEY (PROGRAM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROGRAM_DETAIL ADD CONSTRAINT PROGRAMDT_PK PRIMARY KEY (PROGRAM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_PK PRIMARY KEY (PROJECT_ALLOCATION_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TIMESHEET ADD CONSTRAINT TIMESHEET_PK PRIMARY KEY(TIMESHEET_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROFILE ADD CONSTRAINT PROFILE_PK PRIMARY KEY(PROFILE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROFILE_SKILL_LOOKUP ADD CONSTRAINT PROSKILL_PK PRIMARY KEY	(PROFILE_ID, SKILL_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROFILE_COMPETENCY_LOOKUP ADD CONSTRAINT PROCOMPETENCY_PK PRIMARY KEY (PROFILE_ID, COMPETENCY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CHARGECODE ADD CONSTRAINT CHARGECODE_PK PRIMARY KEY (CHARGECODE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TIMECODE ADD CONSTRAINT TIMECODE_PK PRIMARY KEY (TIMECODE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE TIMESHEET_TIMECODE_LOOKUP ADD CONSTRAINT TSTC_PK PRIMARY KEY(TIMESHEET_ID, TIMECODE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE OPERATING_TERRITORY ADD CONSTRAINT OPTERRITORY_PK PRIMARY KEY (TERRITORY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE COUNTRY ADD CONSTRAINT COUNTRY_PK PRIMARY KEY (COUNTRY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE PROVINCE_STATE ADD CONSTRAINT PROVSTATE_PK PRIMARY KEY (PROVINCE_STATE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE CITY ADD CONSTRAINT CITY_PK PRIMARY KEY (CITY_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ORGANIZATION ADD CONSTRAINT ORGANIZATION_PK PRIMARY KEY (ORGANIZATION_ID) USING INDEX TABLESPACE  VNF_IDX;

-- FOREIGN KEY CONSTRAINTS

ALTER TABLE ACTIVITY_DETAIL ADD CONSTRAINT ACTDET_FK1 FOREIGN KEY (ACTIVITY_ID) 
	REFERENCES ACTIVITY (ACTIVITY_ID);
	
ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK1 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK2 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK3 FOREIGN KEY (FAILED_BUILD)
	REFERENCES BUILD (BUILD_ID);

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK4 FOREIGN KEY (VALIDATION_BUILD)
	REFERENCES BUILD (BUILD_ID);

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK5 FOREIGN KEY (NOTEST_BUILD)
	REFERENCES BUILD (BUILD_ID);

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK6 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);
	
ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK7 FOREIGN KEY (ACTIVITY_CLASS_ID)
	REFERENCES ACTIVITY_CLASSIFICATION (ACTIVITY_CLASS_ID);	

ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK8 FOREIGN KEY (FILE_STREAM_ID)
	REFERENCES FILE_STREAM (FILE_STREAM_ID);
	
ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK9 FOREIGN KEY(PROFILE_ID)
	REFERENCES PROFILE (PROFILE_ID);	
	
ALTER TABLE ACTIVITY ADD CONSTRAINT ACTIVITY_FK10 FOREIGN KEY(CHARGECODE_ID)
	REFERENCES CHARGECODE (CHARGECODE_ID);

ALTER TABLE REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_FK1 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);
	
ALTER TABLE REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_FK2 FOREIGN KEY (ACTIVITY_ID)
	REFERENCES ACTIVITY (ACTIVITY_ID);	

ALTER TABLE COMPONENT ADD CONSTRAINT COMPONENT_FK1 FOREIGN KEY (PRODUCT_ID)
	REFERENCES PRODUCT (PRODUCT_ID);

ALTER TABLE COMPONENT ADD CONSTRAINT COMPONENT_FK3 FOREIGN KEY (COMPONENT_CLASS_ID)
	REFERENCES COMPONENT_CLASSIFICATION(COMPONENT_CLASS_ID);
		
ALTER TABLE PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);
	
ALTER TABLE PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_FK2 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);	

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK2 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK3 FOREIGN KEY (BASELINE_ID)
	REFERENCES PROJECT_BASELINE (BASELINE_ID);

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK4 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK5 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK6 FOREIGN KEY (PROJECT_TYPE_ID)
	REFERENCES PROJECT_TYPE (PROJECT_TYPE_ID);

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK7 FOREIGN KEY (BUILD_CLASS_ID)
	REFERENCES BUILD_CLASSIFICATION (BUILD_CLASS_ID);
	
ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK8 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE BUILD ADD CONSTRAINT BUILD_FK9 FOREIGN KEY (TEAM_ID)
	REFERENCES TEAM (TEAM_ID);	 	
		
ALTER TABLE PROJECT_DETAIL ADD CONSTRAINT PROJECT_DETAIL_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK1 FOREIGN KEY (PLANNED_ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK2 FOREIGN KEY (ACTUAL_ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK3 FOREIGN KEY (RELEASE_ID)
	REFERENCES RELEASE (RELEASE_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK4 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK5 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK7 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);

ALTER TABLE REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK8 FOREIGN KEY (REQUIREMENT_CLASS_ID)
	REFERENCES REQUIREMENT_CLASSIFICATION (REQUIREMENT_CLASS_ID);
	
ALTER TABLE REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_FK2 FOREIGN KEY (RESOURCE_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);	

ALTER TABLE "RESOURCE" ADD CONSTRAINT RESOURCE_FK1 FOREIGN KEY (POOL_ID)
	REFERENCES POOL (POOL_ID);
	
ALTER TABLE "RESOURCE" ADD CONSTRAINT RESOURCE_FK2 FOREIGN KEY (CITY_ID)
	REFERENCES CITY (CITY_ID);

ALTER TABLE "RESOURCE" ADD CONSTRAINT RESOURCE_FK3 FOREIGN KEY (ORGANIZATION_ID)
	REFERENCES ORGANIZATION (ORGANIZATION_ID);	
	
ALTER TABLE RESOURCE_SKILL_LOOKUP ADD CONSTRAINT RESSKILL_FK1 FOREIGN KEY (RESOURCE_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE RESOURCE_SKILL_LOOKUP ADD CONSTRAINT RESSKILL_FK FOREIGN KEY(SKILL_ID)
	REFERENCES SKILL (SKILL_ID);

ALTER TABLE RESOURCE_COMPETENCY_LOOKUP ADD CONSTRAINT RESCOMPETENCY_FK1 FOREIGN KEY (RESOURCE_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE RESOURCE_COMPETENCY_LOOKUP ADD CONSTRAINT RESCOMPETENCY_FK FOREIGN KEY(COMPETENCY_ID)
	REFERENCES COMPETENCY (COMPETENCY_ID);
		
ALTER TABLE TESTSUITE ADD CONSTRAINT TESTSUITE_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE TESTSUITE ADD CONSTRAINT TESTSUITE_FK2 FOREIGN KEY (CONFIGURATION_ID)
	REFERENCES CONFIGURATION (CONFIGURATION_ID);

ALTER TABLE TESTSUITE ADD CONSTRAINT TESTSUITE_FK3 FOREIGN KEY (ASSETREGISTRY_ID)
	REFERENCES ASSETREGISTRY (ASSETREGISTRY_ID);
	
ALTER TABLE TESTSUITE ADD CONSTRAINT TESTSUITE_FK4 FOREIGN KEY (TESTSUITE_CLASS_ID)
	REFERENCES TESTSUITE_CLASSIFICATION (TESTSUITE_CLASS_ID);	
	
ALTER TABLE TESTSUITE ADD CONSTRAINT TESTSUITE_FK5 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);		

ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK2 FOREIGN KEY (BUILD_ID)
	REFERENCES BUILD (BUILD_ID);

ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK3 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK4 FOREIGN KEY (TESTTYPE_ID)
	REFERENCES TESTTYPE (TESTTYPE_ID);

ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK5 FOREIGN KEY (TESTCASE_ID)
	REFERENCES TESTCASE (TESTCASE_ID);
	
ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK6 FOREIGN KEY (EXECRES_CLASS_ID)
	REFERENCES EXECRESULT_CLASSIFICATION (EXECRES_CLASS_ID);
	
ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK7 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	
	
ALTER TABLE EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK8 FOREIGN KEY (TESTSCRIPT_ID)
	REFERENCES TESTSCRIPT (TESTSCRIPT_ID);		
	
ALTER TABLE ITERATION ADD CONSTRAINT ITERATION_FK1 FOREIGN KEY (ASSETREGISTRY_ID)
	REFERENCES ASSETREGISTRY (ASSETREGISTRY_ID);
				
ALTER TABLE ITERATION ADD CONSTRAINT ITERATION_FK4 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);
		
ALTER TABLE ITERATION_DETAIL ADD CONSTRAINT ITERDET_FK1 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);		

ALTER TABLE ITERATION_BASELINE ADD CONSTRAINT ITERBASELINE_FK2 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);
	
ALTER TABLE ITERATION_BASELINE ADD CONSTRAINT ITERBASELINE_FK3 FOREIGN KEY (BASELINE_ID)
	REFERENCES PROJECT_BASELINE (BASELINE_ID);	
	
ALTER TABLE RELEASE ADD CONSTRAINT RELEASE_FK1 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE RELEASE ADD CONSTRAINT RELEASE_FK2 FOREIGN KEY (PRODUCT_ID)
	REFERENCES PRODUCT (PRODUCT_ID);

ALTER TABLE RELEASE ADD CONSTRAINT RELEASE_FK3 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	

ALTER TABLE PROJECT ADD CONSTRAINT PROJECT_FK1 FOREIGN KEY (PROJECT_MANAGER)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE PROJECT ADD CONSTRAINT PROJECT_FK2 FOREIGN KEY (PROJECT_CATEGORY_ID)
	REFERENCES PROJECT_CATEGORY (PROJECT_CATEGORY_ID);	

ALTER TABLE PROJECT ADD CONSTRAINT PROJECT_FK3 FOREIGN KEY (PROJECT_CLASS_ID)
	REFERENCES PROJECT_CLASSIFICATION (PROJECT_CLASS_ID);	
	
ALTER TABLE PROJECT ADD CONSTRAINT PROJECT_FK4 FOREIGN KEY(PROGRAM_ID)
	REFERENCES PROGRAM(PROGRAM_ID);

ALTER TABLE TASK ADD CONSTRAINT TASK_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE TASK ADD CONSTRAINT TASK_FK2 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	

ALTER TABLE TASK ADD CONSTRAINT TASK_FK3 FOREIGN KEY (TASK_CATEGORY_ID)
	REFERENCES TASK_CATEGORY (TASK_CATEGORY_ID);
	
ALTER TABLE TASK ADD CONSTRAINT TASK_FK4 FOREIGN KEY (TASK_CLASS_ID)
	REFERENCES TASK_CLASSIFICATION (TASK_CLASS_ID);	

ALTER TABLE TASK ADD CONSTRAINT TASK_FK5 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);	
	
ALTER TABLE TASK_BASELINE ADD CONSTRAINT TASKBL_FK1 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);

ALTER TABLE TASK_BASELINE ADD CONSTRAINT TASKBL_FK2 FOREIGN KEY (BASELINE_ID)
	REFERENCES PROJECT_BASELINE (BASELINE_ID);	

ALTER TABLE TASK_DETAIL ADD CONSTRAINT TASK_DETAIL_FK1 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);
	
ALTER TABLE PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_FK1 FOREIGN KEY (PARENT_PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_FK2 FOREIGN KEY (CHILD_PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_DETAIL ADD CONSTRAINT PROJECTDT_FK1 FOREIGN KEY (CURRENCY_ID)
	REFERENCES CURRENCY (CURRENCY_ID);

ALTER TABLE PROJECT_TYPE ADD CONSTRAINT PRJTYPE_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_FK2 FOREIGN KEY (PROJECT_TYPE_ID)
	REFERENCES PROJECT_TYPE (PROJECT_TYPE_ID);

ALTER TABLE PROJECT_CATEGORY ADD CONSTRAINT PRJCAT_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE PHASE ADD CONSTRAINT PRJPHASE_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_ROLE ADD CONSTRAINT PRJROLE_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_ROLE ADD CONSTRAINT PRJROLE_FK2 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_FK1 FOREIGN KEY (PROJECT_ROLE_ID)
	REFERENCES PROJECT_ROLE (PROJECT_ROLE_ID);

ALTER TABLE PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_FK2 FOREIGN KEY (RESOURCE_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_FK2 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);

ALTER TABLE CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);
		
ALTER TABLE CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK2 FOREIGN KEY (CONFIGURATION_CLASS_ID)
	REFERENCES CONFIGURATION_CLASSIFICATION (CONFIGURATION_CLASS_ID);	
	
ALTER TABLE CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK3 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	

ALTER TABLE CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_FK1 FOREIGN KEY (CONFIGURATION_ATTRIBUTE_ID)
	REFERENCES CONFIGURATION_ATTRIBUTE (CONFIGURATION_ATTRIBUTE_ID);

ALTER TABLE CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_FK2 FOREIGN KEY (CONFIGURATION_ID)
	REFERENCES CONFIGURATION (CONFIGURATION_ID);

ALTER TABLE TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_FK1 FOREIGN KEY (TESTSUITE_ID)
	REFERENCES TESTSUITE (TESTSUITE_ID);

ALTER TABLE TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_FK2 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE TESTPLAN ADD CONSTRAINT TESTPLAN_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE TESTPLAN ADD CONSTRAINT TESTPLAN_FK2 FOREIGN KEY (ASSETREGISTRY_ID)
	REFERENCES ASSETREGISTRY (ASSETREGISTRY_ID);
	
ALTER TABLE TESTPLAN ADD CONSTRAINT TESTPLAN_FK3 FOREIGN KEY (TESTPLAN_CLASS_ID)
	REFERENCES TESTPLAN_CLASSIFICATION  (TESTPLAN_CLASS_ID);	
	
ALTER TABLE TESTPLAN ADD CONSTRAINT TESTPLAN_FK4 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	
			
ALTER TABLE TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_FK1 FOREIGN KEY (TESTPLAN_ID)
	REFERENCES TESTPLAN (TESTPLAN_ID);

ALTER TABLE TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_FK2 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE TESTCASE ADD CONSTRAINT TESTCASE_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE TESTCASE ADD CONSTRAINT TESTCASE_FK2 FOREIGN KEY (TESTPLAN_ID)
	REFERENCES TESTPLAN (TESTPLAN_ID);
	
ALTER TABLE TESTCASE ADD CONSTRAINT TESTCASE_FK3 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);
			
ALTER TABLE TESTCASE ADD CONSTRAINT TESTCASE_FK4 FOREIGN KEY (TESTCASE_CLASS_ID)
	REFERENCES TESTCASE_CLASSIFICATION (TESTCASE_CLASS_ID);
	
ALTER TABLE TESTCASE ADD CONSTRAINT TESTCASE_FK5 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);			

ALTER TABLE TESTCASE_TESTSCRIPT_LOOKUP ADD CONSTRAINT TESTCSCRIPT_FK1 FOREIGN KEY (TESTCASE_ID)
	REFERENCES TESTCASE (TESTCASE_ID);

ALTER TABLE TESTCASE_TESTSCRIPT_LOOKUP ADD CONSTRAINT TESTCSCRIPT_FK2 FOREIGN KEY (TESTSCRIPT_ID)
	REFERENCES TESTSCRIPT (TESTSCRIPT_ID);
		
ALTER TABLE TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_FK1 FOREIGN KEY (TESTCASE_ID)
	REFERENCES TESTCASE (TESTCASE_ID);

ALTER TABLE TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_FK2 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_FK2 FOREIGN KEY (TESTCASE_ID)
	REFERENCES TESTCASE (TESTCASE_ID);

ALTER TABLE REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_FK2 FOREIGN KEY (TESTPLAN_ID)
	REFERENCES TESTPLAN (TESTPLAN_ID);

ALTER TABLE REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_FK2 FOREIGN KEY (TESTSUITE_ID)
	REFERENCES TESTSUITE (TESTSUITE_ID);

ALTER TABLE REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_FK2 FOREIGN KEY (CREQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);
	
ALTER TABLE REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK1 FOREIGN KEY (PRED_REQUIREMENT_ID)
	REFERENCES  REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK2 FOREIGN KEY (SUCC_REQUIREMENT_ID)
	REFERENCES  REQUIREMENT (REQUIREMENT_ID);	
	
ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK1 FOREIGN KEY (TESTCASE_ID)
	REFERENCES TESTCASE (TESTCASE_ID);

ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK2 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK3 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK4 FOREIGN KEY (TESTTYPE_ID)
	REFERENCES TESTTYPE (TESTTYPE_ID);
	
ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK5 FOREIGN KEY (CONFIGURATION_ID)
	REFERENCES CONFIGURATION (CONFIGURATION_ID);
	
ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK7 FOREIGN KEY (TESTPLAN_ID)
	REFERENCES TESTPLAN (TESTPLAN_ID);
	
ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK9 FOREIGN KEY (EXECWORKIT_CLASS_ID)
	REFERENCES EXECWORKITEM_CLASSIFICATION (EXECWORKIT_CLASS_ID);	
	
ALTER TABLE EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK10 FOREIGN KEY (TESTSCRIPT_ID)
	REFERENCES TESTSCRIPT (TESTSCRIPT_ID);	
	
ALTER TABLE EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXWKIITER_FK1 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXECWKITER_FK2 FOREIGN KEY (EXECWORKITEM_ID)
	REFERENCES EXECUTION_WORKITEM (EXECWORKITEM_ID);

ALTER TABLE REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXWKI_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXECWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
	REFERENCES EXECUTION_WORKITEM (EXECWORKITEM_ID);

ALTER TABLE EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXWKITSU_FK1 FOREIGN KEY (TESTSUITE_ID)
	REFERENCES TESTSUITE (TESTSUITE_ID);

ALTER TABLE EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXECWKTSU_FK2 FOREIGN KEY (EXECWORKITEM_ID)
	REFERENCES EXECUTION_WORKITEM (EXECWORKITEM_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK10 FOREIGN KEY (BUILD_ID)
	REFERENCES BUILD (BUILD_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK11 FOREIGN KEY (PROJECT_CATEGORY_ID)
	REFERENCES PROJECT_CATEGORY (PROJECT_CATEGORY_ID);
	
ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK12 FOREIGN KEY (TEAM_ID)
	REFERENCES TEAM (TEAM_ID);	

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK13 FOREIGN KEY (PHASE_ID)
	REFERENCES PHASE (PHASE_ID);	

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK2 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK3 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK5 FOREIGN KEY (RELEASE_ID)
	REFERENCES RELEASE (RELEASE_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK6 FOREIGN KEY (FIXEDINRELEASE_ID)
	REFERENCES RELEASE (RELEASE_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK7 FOREIGN KEY (REQUEST_CLASS_ID)
	REFERENCES REQUEST_CLASSIFICATION (REQUEST_CLASS_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK8 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE REQUEST ADD CONSTRAINT REQUEST_FK9 FOREIGN KEY (RESOLVER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);	
	
ALTER TABLE REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_FK1 FOREIGN KEY (PARENT_REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_FK2 FOREIGN KEY (CHILD_REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE "FILE" ADD CONSTRAINT FILE_FK1 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);
	
ALTER TABLE "FILE" ADD CONSTRAINT FILE_FK2 FOREIGN KEY (FILE_CLASS_ID)
	REFERENCES FILE_CLASSIFICATION (FILE_CLASS_ID);	
	
ALTER TABLE FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK1 FOREIGN KEY (FILE_ID)
	REFERENCES "FILE" (FILE_ID);	
	
ALTER TABLE FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK2 FOREIGN KEY (AUTHOR_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);	
	
ALTER TABLE FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK3 FOREIGN KEY (ACTIVITY_ID)
	REFERENCES ACTIVITY (ACTIVITY_ID);
	
ALTER TABLE FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK4 FOREIGN KEY (FILE_STREAM_ID)
	REFERENCES FILE_STREAM (FILE_STREAM_ID);	
	
ALTER TABLE FILE_VERSION ADD CONSTRAINT FILE_FK5 FOREIGN KEY (FILE_CLASS_ID)
	REFERENCES FILE_CLASSIFICATION (FILE_CLASS_ID);						
	
ALTER TABLE FILE_BASELINE ADD CONSTRAINT FBASE_FK1 FOREIGN KEY (COMPONENT_ID)
	REFERENCES COMPONENT (COMPONENT_ID);
	
ALTER TABLE FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_FK1 FOREIGN KEY (FILE_BASELINE_ID)
	REFERENCES FILE_BASELINE(FILE_BASELINE_ID);
	
ALTER TABLE FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_FK2 FOREIGN KEY (ACTIVITY_ID)
	REFERENCES ACTIVITY (ACTIVITY_ID);
	
ALTER TABLE FILE_STREAM ADD CONSTRAINT FSTREAM_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE FILE_STREAM ADD CONSTRAINT FSTREAM_FK2 FOREIGN KEY (FILE_STREAM_CLASS_ID)
	REFERENCES FILE_STREAM_CLASSIFICATION (FILE_STREAM_CLASS_ID);		

ALTER TABLE CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT CFGEXECRES_FK1 FOREIGN KEY (CONFIGURATION_ID)
	REFERENCES CONFIGURATION (CONFIGURATION_ID);

ALTER TABLE CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT CFGEXECRES_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
	REFERENCES EXECUTION_RESULT (EXECUTION_RESULT_ID);

ALTER TABLE TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK1 FOREIGN KEY (TESTSUITE_ID)
	REFERENCES TESTSUITE (TESTSUITE_ID);

ALTER TABLE TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK2 FOREIGN KEY (BUILD_ID)
	REFERENCES BUILD (BUILD_ID);

ALTER TABLE TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK3 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);
	
ALTER TABLE TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK4 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);	

ALTER TABLE TESTSUITELOG ADD CONSTRAINT  TESTSUITELOG_FK5 FOREIGN KEY (TESTSUITELOG_CLASS_ID)
	REFERENCES TESTSUITELOG_CLASSIFICATION (TESTSUITELOG_CLASS_ID);

ALTER TABLE TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_FK1 FOREIGN KEY (TESTSUITELOG_ID)
	REFERENCES TESTSUITELOG (TESTSUITELOG_ID);

ALTER TABLE TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
	REFERENCES EXECUTION_RESULT (EXECUTION_RESULT_ID);

ALTER TABLE TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISSU_FK1 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);

ALTER TABLE TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISSU_FK2 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQIREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQREQ_FK2 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_FK1 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK1 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID); 

ALTER TABLE REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_FK2 FOREIGN KEY (CUSTOMER_ID)
	REFERENCES CUSTOMER (CUSTOMER_ID);

ALTER TABLE REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_FK1 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_FK2 FOREIGN KEY (CUSTOMER_ID)
	REFERENCES CUSTOMER (CUSTOMER_ID);

ALTER TABLE EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRESREQ_FK1 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRESREQ_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
	REFERENCES EXECUTION_RESULT (EXECUTION_RESULT_ID);

ALTER TABLE RISK ADD CONSTRAINT RISK_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE RISK ADD CONSTRAINT RISK_FK2 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE RISK ADD CONSTRAINT RISK_FK3 FOREIGN KEY (RELEASE_ID)
	REFERENCES RELEASE (RELEASE_ID);

ALTER TABLE RISK ADD CONSTRAINT RISK_FK4 FOREIGN KEY (ITERATION_ID)
	REFERENCES ITERATION (ITERATION_ID);
	
ALTER TABLE RISK ADD CONSTRAINT RISK_FK5 FOREIGN KEY (REQUIREMENT_ID)
	REFERENCES REQUIREMENT (REQUIREMENT_ID);

ALTER TABLE RISK_STATE_HISTORY ADD CONSTRAINT RISKSTATEHIST_FK1 FOREIGN KEY (RISK_ID)
	REFERENCES RISK (RISK_ID);

ALTER TABLE FACTOR ADD CONSTRAINT FACTOR_FK1 FOREIGN KEY (RISK_ID)
	REFERENCES RISK (RISK_ID);

ALTER TABLE PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK2 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);

ALTER TABLE PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK3 FOREIGN KEY (FILE_STREAM_ID)
	REFERENCES FILE_STREAM (FILE_STREAM_ID);

ALTER TABLE PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_FK1 FOREIGN KEY (BASELINE_ID)
	REFERENCES PROJECT_BASELINE (BASELINE_ID);

ALTER TABLE PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_FK2 FOREIGN KEY (COMPBASELINE_ID)
	REFERENCES PROJECT_BASELINE (BASELINE_ID);

ALTER TABLE "COMMENT" ADD CONSTRAINT COMMENT_FK1 FOREIGN KEY (RESPONSE_COMMENT_ID)
	REFERENCES "COMMENT" (COMMENT_ID);

ALTER TABLE "COMMENT" ADD CONSTRAINT COMMENT_FK2 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE" (RESOURCE_ID);

ALTER TABLE "COMMENT" ADD CONSTRAINT COMMENT_FK3 FOREIGN KEY (REQUEST_ID)
	REFERENCES REQUEST (REQUEST_ID);

ALTER TABLE "COMMENT" ADD CONSTRAINT COMMENT_FK4 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);

ALTER TABLE "COMMENT" ADD CONSTRAINT COMMENT_FK5 FOREIGN KEY (ACTIVITY_ID)
	REFERENCES ACTIVITY (ACTIVITY_ID);

ALTER TABLE PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_FK1 FOREIGN KEY(PARENT_WKCFG_ID)
	REFERENCES PROJECT_WORKCONFIGURATION (PROJECT_WKCFG_ID);

ALTER TABLE PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_FK2 FOREIGN KEY(CHILD_WKCFG_ID)
	REFERENCES PROJECT_WORKCONFIGURATION (PROJECT_WKCFG_ID);

ALTER TABLE EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_FK1 FOREIGN KEY (EXECUTION_RESULT_ID)
	REFERENCES EXECUTION_RESULT (EXECUTION_RESULT_ID);

ALTER TABLE EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
		REFERENCES EXECUTION_WORKITEM (EXECWORKITEM_ID);

ALTER TABLE CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_FK1 FOREIGN KEY (CONFIGURATION_ID)
		REFERENCES CONFIGURATION (CONFIGURATION_ID);

ALTER TABLE CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
		REFERENCES EXECUTION_WORKITEM (EXECWORKITEM_ID);
		
ALTER TABLE TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_FK1 FOREIGN KEY (TEST_CATEGORY_ID)
		REFERENCES TEST_CATEGORY (TEST_CATEGORY_ID);

ALTER TABLE TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_FK2 FOREIGN KEY (TESTPLAN_ID)
		REFERENCES TESTPLAN (TESTPLAN_ID);

ALTER TABLE TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_FK1 FOREIGN KEY (TEST_CATEGORY_ID)
		REFERENCES TEST_CATEGORY (TEST_CATEGORY_ID);

ALTER TABLE TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_FK2 FOREIGN KEY (TESTCASE_ID)
		REFERENCES TESTCASE (TESTCASE_ID);

ALTER TABLE TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_FK1 FOREIGN KEY (TESTCASE_ID)
		REFERENCES TESTCASE (TESTCASE_ID);
		
ALTER TABLE TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_FK2 FOREIGN KEY (TESTSUITE_ID)
		REFERENCES TESTSUITE (TESTSUITE_ID);		

ALTER TABLE TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_FK1 FOREIGN KEY (TESTSUITE_ID)
		REFERENCES TESTSUITE (TESTSUITE_ID);

ALTER TABLE TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_FK2 FOREIGN KEY (TESTSUITELOG_ID)
		REFERENCES TESTSUITELOG (TESTSUITELOG_ID);

ALTER TABLE TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_FK1 FOREIGN KEY (PARENT_TESTPLAN_ID)
		REFERENCES TESTPLAN (TESTPLAN_ID);

ALTER TABLE TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_FK2 FOREIGN KEY (CHILD_TESTPLAN_ID)
		REFERENCES TESTPLAN (TESTPLAN_ID);

ALTER TABLE TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_FK1 FOREIGN KEY (TESTPLAN_ID)
	REFERENCES TESTPLAN(TESTPLAN_ID);
	
ALTER TABLE TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_FK2 FOREIGN KEY (TESTCASE_ID)
	REFERENCES TESTCASE (TESTCASE_ID);	

ALTER TABLE LAB_RESOURCE ADD CONSTRAINT LABRES_FK1 FOREIGN KEY (RESOURCE_GROUP_ID)
	REFERENCES RESOURCE_GROUP (RESOURCE_GROUP_ID);	
	
ALTER TABLE LAB_RESOURCE ADD CONSTRAINT LABRES_FK2 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	

ALTER TABLE RESOURCE_GROUP ADD CONSTRAINT RESGRP_FK1 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);
	
ALTER TABLE RESERVATION ADD CONSTRAINT RESERV_FK1 FOREIGN KEY (LAB_RESOURCE_ID)
	REFERENCES LAB_RESOURCE (LAB_RESOURCE_ID);
	
ALTER TABLE RESERVATION ADD CONSTRAINT RESERV_FK2 FOREIGN KEY (PROJECT_ID)
	REFERENCES PROJECT (PROJECT_ID);	
	
ALTER TABLE ACTIVITY_STATE_HISTORY ADD CONSTRAINT ACTSTH_FK1 FOREIGN KEY (ACTIVITY_ID)
	REFERENCES ACTIVITY (ACTIVITY_ID);
	
ALTER TABLE TASK_STATE_HISTORY ADD CONSTRAINT TSKSTH_FK1 FOREIGN KEY (TASK_ID)
	REFERENCES TASK (TASK_ID);
	
ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK1 FOREIGN KEY (REQUEST_CLASS_ID)
		REFERENCES REQUEST_CLASSIFICATION (REQUEST_CLASS_ID);

ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK2 FOREIGN KEY (REQUEST_ID)
		REFERENCES  REQUEST (REQUEST_ID);                          

ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK3 FOREIGN KEY (PREV_TEAM_ID)
		REFERENCES  TEAM (TEAM_ID);    
                       
ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK4 FOREIGN KEY (PREV_REQUEST_CATEGORY_ID)
		REFERENCES  REQUEST_CATEGORY (REQUEST_CATEGORY_ID);  
              
ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK5 FOREIGN KEY (PREV_ITERATION_ID)
		REFERENCES  ITERATION (ITERATION_ID);     
                                       
ALTER TABLE REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK6 FOREIGN KEY (PREV_OWNER_ID)
		REFERENCES  "RESOURCE" (RESOURCE_ID);
		
ALTER TABLE BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_FK1 FOREIGN KEY (COMPONENT_ID)
		REFERENCES COMPONENT (COMPONENT_ID);
		
ALTER TABLE BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_FK2 FOREIGN KEY (BUILD_ID)
		REFERENCES BUILD (BUILD_ID);
		
ALTER TABLE BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_FK1 FOREIGN KEY (COMPONENT_ID)
		REFERENCES COMPONENT (COMPONENT_ID);
		
ALTER TABLE BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_FK2 FOREIGN KEY (BUILD_ID)
		REFERENCES BUILD (BUILD_ID);
		
ALTER TABLE BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_FK1 FOREIGN KEY (COMPONENT_ID)
		REFERENCES COMPONENT (COMPONENT_ID);
		
ALTER TABLE BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_FK2 FOREIGN KEY (BUILD_ID)
		REFERENCES BUILD (BUILD_ID);
				
ALTER TABLE UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK1 FOREIGN KEY (COMPONENT_ID)
		REFERENCES COMPONENT (COMPONENT_ID);
		
ALTER TABLE UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK2 FOREIGN KEY (PROJECT_ID)
		REFERENCES PROJECT (PROJECT_ID);
		
ALTER TABLE UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK3 FOREIGN KEY (TEAM_ID)
		REFERENCES TEAM(TEAM_ID);

ALTER TABLE JOB ADD CONSTRAINT JOB_FK1 FOREIGN KEY (OWNER_ID)
		REFERENCES "RESOURCE" (RESOURCE_ID);
		
ALTER TABLE JOB ADD CONSTRAINT JOB_FK2 FOREIGN KEY (PROJECT_ID)
		REFERENCES PROJECT (PROJECT_ID);		
		
ALTER TABLE JOB_RESULT ADD CONSTRAINT JOBRES_FK1 FOREIGN KEY (OWNER_ID)
		REFERENCES "RESOURCE" (RESOURCE_ID);		
		
ALTER TABLE JOB_RESULT ADD CONSTRAINT JOBRES_FK2 FOREIGN KEY (JOB_ID)
		REFERENCES JOB (JOB_ID);	
		
ALTER TABLE JOB_RESULT ADD CONSTRAINT JOBRES_FK3 FOREIGN KEY (LAB_RESOURCE_ID)
		REFERENCES LAB_RESOURCE (LAB_RESOURCE_ID);		
	
ALTER TABLE TESTSCRIPT ADD CONSTRAINT TESTSCRIPT_FK1 FOREIGN KEY (OWNER_ID)
	REFERENCES "RESOURCE"(RESOURCE_ID);	

ALTER TABLE PROGRAM ADD CONSTRAINT PROGRAM_FK1 FOREIGN KEY (PROGRAM_MANAGER)
	REFERENCES "RESOURCE" (RESOURCE_ID);		

ALTER TABLE PROGRAM_DETAIL ADD CONSTRAINT PROGRAM_DETAIL_FK1 FOREIGN KEY (PROGRAM_ID)
	REFERENCES PROGRAM (PROGRAM_ID);
		
ALTER TABLE PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_FK1 FOREIGN KEY (PROJECT_ID)
		REFERENCES PROJECT (PROJECT_ID);


ALTER TABLE PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_FK2 FOREIGN KEY (OWNER_ID)
		REFERENCES "RESOURCE" (RESOURCE_ID);
		
ALTER TABLE PROJECT_ALLOCATION ADD CONSTRAINT PROJALLO_FK3 FOREIGN KEY (PROFILE_ID)
	REFERENCES PROFILE (PROFILE_ID);			
		
ALTER TABLE TIMESHEET ADD CONSTRAINT TIMESHEET_FK1 FOREIGN KEY (ACTIVITY_ID)
	REFERENCES ACTIVITY	(ACTIVITY_ID);
	
ALTER TABLE TIMESHEET ADD CONSTRAINT TIMESHEET_FK2 FOREIGN KEY (APPROVER_ID)
	REFERENCES "RESOURCE"	(RESOURCE_ID);

ALTER TABLE PROFILE ADD CONSTRAINT PROFILE_FK1 FOREIGN KEY(CITY_ID) 
	REFERENCES CITY(CITY_ID);

ALTER TABLE PROFILE ADD CONSTRAINT PROFILE_FK2 FOREIGN KEY(ORGANIZATION_ID) 
	REFERENCES ORGANIZATION (ORGANIZATION_ID);
	
ALTER TABLE PROFILE_SKILL_LOOKUP ADD CONSTRAINT PROSKILL_FK1 FOREIGN KEY(SKILL_ID) 
	REFERENCES SKILL(SKILL_ID);

ALTER TABLE PROFILE_SKILL_LOOKUP ADD CONSTRAINT PROSKILL_FK2 FOREIGN KEY(PROFILE_ID)
	REFERENCES PROFILE(PROFILE_ID);
	
ALTER TABLE PROFILE_COMPETENCY_LOOKUP ADD CONSTRAINT PROCOMPETENCY_FK1 FOREIGN KEY(COMPETENCY_ID) 
	REFERENCES COMPETENCY(COMPETENCY_ID);

ALTER TABLE PROFILE_COMPETENCY_LOOKUP ADD CONSTRAINT PROCOMPETENCY_FK2 FOREIGN KEY(PROFILE_ID)
	REFERENCES PROFILE(PROFILE_ID);
	
ALTER TABLE TIMESHEET_TIMECODE_LOOKUP ADD CONSTRAINT TSTC_FK1 FOREIGN KEY (TIMESHEET_ID)
	REFERENCES TIMESHEET (TIMESHEET_ID);

ALTER TABLE TIMESHEET_TIMECODE_LOOKUP ADD CONSTRAINT TSTC_FK2 FOREIGN KEY(TIMECODE_ID)
	REFERENCES TIMECODE(TIMECODE_ID);
							
ALTER TABLE COUNTRY ADD CONSTRAINT COUNTRY_FK1 FOREIGN KEY (TERRITORY_ID)
	REFERENCES OPERATING_TERRITORY (TERRITORY_ID);
	
ALTER TABLE PROVINCE_STATE ADD CONSTRAINT PROVSTATE_FK1 FOREIGN KEY (COUNTRY_ID)
	REFERENCES COUNTRY (COUNTRY_ID);

ALTER TABLE CITY ADD CONSTRAINT CITY_FK1 FOREIGN KEY (PROVINCE_STATE_ID)
	REFERENCES PROVINCE_STATE (PROVINCE_STATE_ID);
								
--LOOKUP HIERARCHY TRIGGERS
   
CREATE TRIGGER TRG_REQCUSTD
	AFTER UPDATE OF REC_DATETIME ON REQUEST
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUEST_CUSTOMER_LOOKUP WHERE REQUEST_ID=:NEW.REQUEST_ID; 
END;
/       

    
CREATE TRIGGER TRG_REQREQUI
	AFTER UPDATE OF REC_DATETIME ON REQUEST
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_REQUEST_LOOKUP WHERE REQUEST_ID=:NEW.REQUEST_ID; 
END;
/     

    
CREATE TRIGGER TRG_REQTASK
	AFTER UPDATE OF REC_DATETIME ON REQUEST
	FOR EACH ROW 
BEGIN 

    DELETE FROM TASK_REQUEST_LOOKUP WHERE REQUEST_ID=:NEW.REQUEST_ID; 
END;
/    

    
CREATE TRIGGER TRG_REQLOG
	AFTER UPDATE OF REC_DATETIME ON REQUEST
	FOR EACH ROW 
BEGIN 

    DELETE FROM EXECRES_REQUEST_LOOKUP WHERE REQUEST_ID=:NEW.REQUEST_ID; 
END;
/        

    
CREATE TRIGGER TRG_REQREQ
	AFTER UPDATE OF REC_DATETIME ON REQUEST
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUEST_HIERARCHY WHERE PARENT_REQUEST_ID=:NEW.REQUEST_ID OR CHILD_REQUEST_ID=:NEW.REQUEST_ID; 
END;
/             

    

CREATE TRIGGER TRG_EXWKIITDD
	AFTER UPDATE OF REC_DATETIME ON EXECUTION_WORKITEM
	FOR EACH ROW 
BEGIN 

    DELETE FROM EXECWORKITEM_ITERATION_LOOKUP WHERE EXECWORKITEM_ID=:NEW.EXECWORKITEM_ID; 
END;
/    

    
    
CREATE TRIGGER TRG_EXWKITSUD
	AFTER UPDATE OF REC_DATETIME ON EXECUTION_WORKITEM
	FOR EACH ROW 
BEGIN 

    DELETE FROM EXECWORKITEM_TESTSUITE_LOOKUP WHERE EXECWORKITEM_ID=:NEW.EXECWORKITEM_ID; 
END;
/      

    
CREATE TRIGGER TRG_CONFATTRD
	AFTER UPDATE OF REC_DATETIME ON CONFIGURATION
	FOR EACH ROW 
BEGIN 

    DELETE FROM CONFIGURATION_ATTRIBUTE_LOOKUP WHERE CONFIGURATION_ID=:NEW.CONFIGURATION_ID; 
END;
/       


CREATE TRIGGER TRG_CONFTLGD
	AFTER UPDATE OF REC_DATETIME ON CONFIGURATION
	FOR EACH ROW 
BEGIN 

    DELETE FROM CONFIG_EXECUTIONRES_LOOKUP WHERE CONFIGURATION_ID=:NEW.CONFIGURATION_ID; 
END;
/       


CREATE TRIGGER TRG_PRJBSLND
	AFTER UPDATE OF REC_DATETIME ON PROJECT_BASELINE
	FOR EACH ROW 
BEGIN 

    DELETE FROM PROJ_BASELINE_BASELINE_LOOKUP WHERE BASELINE_ID=:NEW.BASELINE_ID OR COMPBASELINE_ID=:NEW.BASELINE_ID; 
END;
/ 


CREATE TRIGGER TRG_PRJROLED
	AFTER UPDATE OF REC_DATETIME ON PROJECT_ROLE
	FOR EACH ROW 
BEGIN 

    DELETE FROM PROJECT_ROLE_MEMBER_LOOKUP WHERE PROJECT_ROLE_ID=:NEW.PROJECT_ROLE_ID; 
END;
/ 


CREATE TRIGGER TRG_REQUITSTCD
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_EXECWRKITEM_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/ 

    
CREATE TRIGGER TRG_REQICUSTD
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_CUSTOMER_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/     


CREATE TRIGGER TRG_REQIREQUID
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_REQUIREMENT_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID OR CREQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/    

        
CREATE TRIGGER TRG_REQITSTCD
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_TESTCASE_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/    


CREATE TRIGGER TRG_REQITPLND
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_TESTPLAN_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/    


CREATE TRIGGER TRG_REQITSUTD
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUIREMENT_TESTSUITE_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/  


CREATE TRIGGER TRG_TSLOG
	AFTER UPDATE OF REC_DATETIME ON TESTSUITELOG
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTSUITELOG_EXECRESULT_LOOKUP WHERE TESTSUITELOG_ID=:NEW.TESTSUITELOG_ID; 
END;
/  


CREATE TRIGGER TRG_TSKREQID
	AFTER UPDATE OF REC_DATETIME ON REQUIREMENT
	FOR EACH ROW 
BEGIN 

    DELETE FROM TASK_REQUIREMENT_LOOKUP WHERE REQUIREMENT_ID=:NEW.REQUIREMENT_ID; 
END;
/  


CREATE TRIGGER TRG_TSCITERD
	AFTER UPDATE OF REC_DATETIME ON TESTCASE
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTCASE_ITERATION_LOOKUP WHERE TESTCASE_ID=:NEW.TESTCASE_ID; 
END;
/  


CREATE TRIGGER TRG_TPLNITERD
	AFTER UPDATE OF REC_DATETIME ON TESTPLAN
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTPLAN_ITERATION_LOOKUP WHERE TESTPLAN_ID=:NEW.TESTPLAN_ID; 
END;
/  


CREATE TRIGGER TRG_TSUTITERD
	AFTER UPDATE OF REC_DATETIME ON TESTSUITE
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTSUITE_ITERATION_LOOKUP WHERE TESTSUITE_ID=:NEW.TESTSUITE_ID; 
END;
/  


CREATE TRIGGER TRG_PRJHIERD
	AFTER UPDATE OF REC_DATETIME ON PROJECT
	FOR EACH ROW 
BEGIN 

    DELETE FROM PROJECT_HIERARCHY WHERE PARENT_PROJECT_ID=:NEW.PROJECT_ID OR CHILD_PROJECT_ID=:NEW.PROJECT_ID; 
END;
/  


CREATE TRIGGER TRG_PRJCOMPD
	AFTER UPDATE OF REC_DATETIME ON PROJECT
	FOR EACH ROW 
BEGIN 

    DELETE FROM PROJECT_COMPONENT_LOOKUP WHERE PROJECT_ID=:NEW.PROJECT_ID; 
END;
/  


CREATE TRIGGER TRG_FBSACTD
	AFTER UPDATE OF REC_DATETIME ON ACTIVITY
	FOR EACH ROW 
BEGIN 

    DELETE FROM FILE_BASELINE_ACTIVITY_LOOKUP WHERE ACTIVITY_ID=:NEW.ACTIVITY_ID; 
END;
/  


CREATE TRIGGER TRG_REQACTD
	AFTER UPDATE OF REC_DATETIME ON REQUEST
	FOR EACH ROW 
BEGIN 

    DELETE FROM REQUEST_ACTIVITY_LOOKUP WHERE REQUEST_ID=:NEW.REQUEST_ID; 
END;
/  

  
CREATE TRIGGER TRG_EXERESWKIT
	AFTER UPDATE OF REC_DATETIME ON EXECUTION_RESULT
	FOR EACH ROW 
BEGIN 

    DELETE FROM EXECRES_EXECWKITEM_LOOKUP WHERE EXECUTION_RESULT_ID=:NEW.EXECUTION_RESULT_ID; 
END;
/  


CREATE TRIGGER TRG_CFGEXECWK
	AFTER UPDATE OF REC_DATETIME ON EXECUTION_WORKITEM
	FOR EACH ROW 
BEGIN 

    DELETE FROM CONFIG_EXECUTIONWORKITM_LOOKUP WHERE EXECWORKITEM_ID=:NEW.EXECWORKITEM_ID; 
END;
/  


CREATE TRIGGER TRG_TPLNCAT
	AFTER UPDATE OF REC_DATETIME ON TESTPLAN
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTPLAN_CATEGORY_LOOKUP WHERE TESTPLAN_ID=:NEW.TESTPLAN_ID; 
END;
/  

    
    
CREATE TRIGGER TRG_TCASECAT
	AFTER UPDATE OF REC_DATETIME ON TESTCASE
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTCASE_CATEGORY_LOOKUP WHERE TESTCASE_ID=:NEW.TESTCASE_ID; 
END;
/ 


CREATE TRIGGER TRG_TSUTCASE
	AFTER UPDATE OF REC_DATETIME ON TESTCASE
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTSUITE_TESTCASE_LOOKUP WHERE TESTCASE_ID=:NEW.TESTCASE_ID; 
END;
/ 

    
CREATE TRIGGER TRG_TSUTLG
	AFTER UPDATE OF REC_DATETIME ON TESTSUITE
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTSUITE_TESTSUITELOG_LOOKUP WHERE TESTSUITE_ID=:NEW.TESTSUITE_ID; 
END;
/                 


CREATE TRIGGER TRG_TPLNTCS
	AFTER UPDATE OF REC_DATETIME ON TESTPLAN
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTPLAN_TESTCASE_LOOKUP WHERE TESTPLAN_ID=:NEW.TESTPLAN_ID; 
END;
/                 

CREATE TRIGGER TRG_TSCSCRIPT
	AFTER UPDATE OF REC_DATETIME ON TESTCASE
	FOR EACH ROW 
BEGIN 

    DELETE FROM TESTCASE_TESTSCRIPT_LOOKUP WHERE TESTCASE_ID=:NEW.TESTCASE_ID; 
END;
/  


CREATE TRIGGER TRG_SKILLRES 
	AFTER UPDATE OF REC_DATETIME ON "RESOURCE"
	FOR EACH ROW 
BEGIN 

    DELETE FROM RESOURCE_SKILL_LOOKUP WHERE RESOURCE_ID=:NEW.RESOURCE_ID; 
END;
/
 
CREATE TRIGGER TRG_COMPRES 
	AFTER UPDATE OF REC_DATETIME ON "RESOURCE"
	FOR EACH ROW 
BEGIN 

    DELETE FROM RESOURCE_COMPETENCY_LOOKUP WHERE RESOURCE_ID=:NEW.RESOURCE_ID; 
END;
/
      
CREATE TRIGGER TRG_SKILLPRO 
	AFTER UPDATE OF REC_DATETIME ON PROFILE
	FOR EACH ROW 
BEGIN 

    DELETE FROM PROFILE_SKILL_LOOKUP WHERE PROFILE_ID=:NEW.PROFILE_ID; 
END;
/
 
CREATE TRIGGER TRG_COMPPRO 
	AFTER UPDATE OF REC_DATETIME ON PROFILE
	FOR EACH ROW 
BEGIN 

    DELETE FROM PROFILE_COMPETENCY_LOOKUP WHERE PROFILE_ID=:NEW.PROFILE_ID; 
END;
/

CREATE TRIGGER TRG_TSTC
	AFTER UPDATE OF REC_DATETIME ON TIMESHEET
	FOR EACH ROW 
BEGIN 

    DELETE FROM TIMESHEET_TIMECODE_LOOKUP WHERE TIMESHEET_ID=:NEW.TIMESHEET_ID; 
END;
/

COMMIT;
